/* This file is automatically generated by i386-gen.  Do not edit!  */
/* Copyright (C) 2007-2025 Free Software Foundation, Inc.

   This file is part of the GNU opcodes library.

   This library is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3, or (at your option)
   any later version.

   It is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
   or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
   License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin Street - Fifth Floor, Boston,
   MA 02110-1301, USA.  */

static const char i386_mnemonics[];

#define MN_ud0 0x1
#define MN_prefetcht0 0x5
#define MN_prefetchit0 0x10
#define MN_t2rpntlvwz0 0x1c
#define MN_xsha1 0x28
#define MN_fld1 0x2e
#define MN_ud1 0x33
#define MN_sha1msg1 0x37
#define MN_vsha512msg1 0x40
#define MN_vsm3msg1 0x4c
#define MN_sha256msg1 0x55
#define MN_fprem1 0x60
#define MN_f2xm1 0x67
#define MN_fyl2xp1 0x6d
#define MN_t2rpntlvwz0t1 0x75
#define MN_t2rpntlvwz1t1 0x83
#define MN_tileloaddt1 0x91
#define MN_prefetcht1 0x9d
#define MN_prefetchit1 0xa8
#define MN_pfrcpit1 0xb4
#define MN_pfrsqit1 0xbd
#define MN_int1 0xc6
#define MN_t2rpntlvwz0rst1 0xcb
#define MN_t2rpntlvwz1rst1 0xdb
#define MN_tileloaddrst1 0xeb
#define MN_prefetchwt1 0xf9
#define MN_t2rpntlvwz1 0x105
#define MN_xsha512 0x111
#define MN_vmovdqa32 0x119
#define MN_data32 0x123
#define MN_crc32 0x12a
#define MN_endbr32 0x130
#define MN_addr32 0x138
#define MN_vmovdqu32 0x13f
#define MN_ud2 0x149
#define MN_fldlg2 0x14d
#define MN_xrng2 0x154
#define MN_sha1msg2 0x15a
#define MN_vsha512msg2 0x163
#define MN_vsm3msg2 0x16f
#define MN_sha256msg2 0x178
#define MN_push2 0x183
#define MN_montmul2 0x189
#define MN_sm2 0x192
#define MN_fldln2 0x196
#define MN_pop2 0x19d
#define MN_vsha512rnds2 0x1a2
#define MN_vsm3rnds2 0x1af
#define MN_sha256rnds2 0x1b9
#define MN_prefetcht2 0x1c5
#define MN_pfrcpit2 0x1d0
#define MN_prefetchrst2 0x1d9
#define MN_vbroadcastf32x2 0x1e6
#define MN_vbroadcasti32x2 0x1f6
#define MN_vshuff64x2 0x206
#define MN_vextractf64x2 0x211
#define MN_vinsertf64x2 0x21f
#define MN_vbroadcastf64x2 0x22c
#define MN_vshufi64x2 0x23c
#define MN_vextracti64x2 0x247
#define MN_vinserti64x2 0x255
#define MN_vbroadcasti64x2 0x262
#define MN_sm3 0x272
#define MN_int3 0x276
#define MN_vmovdqa64 0x27b
#define MN_xsavec64 0x285
#define MN_xsave64 (MN_fxsave64 + 1)
#define MN_fxsave64 0x28e
#define MN_endbr64 0x297
#define MN_xrstor64 (MN_fxrstor64 + 1)
#define MN_fxrstor64 0x29f
#define MN_xsaves64 0x2a9
#define MN_xrstors64 0x2b2
#define MN_xsaveopt64 0x2bc
#define MN_vmovdqu64 0x2c7
#define MN_rex64 0x2d1
#define MN_xsha384 0x2d7
#define MN_sm4 0x2df
#define MN_sha1rnds4 0x2e3
#define MN_vsm4rnds4 0x2ed
#define MN_vshuff32x4 0x2f7
#define MN_vextractf32x4 0x302
#define MN_vinsertf32x4 0x310
#define MN_vbroadcastf32x4 0x31d
#define MN_vshufi32x4 0x32d
#define MN_vextracti32x4 0x338
#define MN_vinserti32x4 0x346
#define MN_vbroadcasti32x4 0x353
#define MN_vextractf64x4 0x363
#define MN_vinsertf64x4 0x371
#define MN_vbroadcastf64x4 0x37e
#define MN_vextracti64x4 0x38e
#define MN_vinserti64x4 0x39c
#define MN_vbroadcasti64x4 0x3a9
#define MN_vsm4key4 0x3b9
#define MN_data16 0x3c2
#define MN_vfmsub231bf16 0x3c9
#define MN_vfnmsub231bf16 0x3d7
#define MN_vfmadd231bf16 0x3e6
#define MN_vfnmadd231bf16 0x3f4
#define MN_vfmsub132bf16 0x403
#define MN_vfnmsub132bf16 0x411
#define MN_vfmadd132bf16 0x420
#define MN_vfnmadd132bf16 0x42e
#define MN_vcvtne2ps2bf16 0x43d
#define MN_vcvtneps2bf16 0x44c
#define MN_vfmsub213bf16 0x45a
#define MN_vfnmsub213bf16 0x468
#define MN_vfmadd213bf16 0x477
#define MN_vfnmadd213bf16 0x485
#define MN_vsubbf16 0x494
#define MN_vaddbf16 0x49d
#define MN_vreducebf16 0x4a6
#define MN_vrndscalebf16 0x4b2
#define MN_vscalefbf16 0x4c0
#define MN_vmulbf16 0x4cc
#define MN_vminbf16 0x4d5
#define MN_vrcpbf16 0x4de
#define MN_vcmpbf16 0x4e7
#define MN_vgetexpbf16 0x4f0
#define MN_vcomisbf16 0x4fc
#define MN_vfpclassbf16 0x507
#define MN_vgetmantbf16 0x514
#define MN_vrsqrtbf16 0x521
#define MN_vsqrtbf16 0x52c
#define MN_vdivbf16 0x536
#define MN_vminmaxbf16 0x53f
#define MN_vmaxbf16 0x54b
#define MN_tconjtfp16 0x554
#define MN_addr16 0x55f
#define MN_vmovdqu16 0x566
#define MN_xsha256 0x570
#define MN_encodekey256 0x578
#define MN_vperm2f128 0x585
#define MN_vextractf128 0x590
#define MN_vinsertf128 0x59d
#define MN_vbroadcastf128 0x5a9
#define MN_vperm2i128 0x5b8
#define MN_vextracti128 0x5c3
#define MN_vinserti128 0x5d0
#define MN_vbroadcasti128 0x5dc
#define MN_encodekey128 0x5eb
#define MN_vcvt2ph2bf8 0x5f8
#define MN_vcvtbiasph2bf8 0x604
#define MN_vcvtph2bf8 0x613
#define MN_vcvt2ph2hf8 0x61e
#define MN_vcvtbiasph2hf8 0x62a
#define MN_vcvtph2hf8 0x639
#define MN_vmovdqu8 0x644
#define MN_vextractf32x8 0x64d
#define MN_vinsertf32x8 0x65b
#define MN_vbroadcastf32x8 0x668
#define MN_vextracti32x8 0x678
#define MN_vinserti32x8 0x686
#define MN_vbroadcasti32x8 0x693
#define MN_ud2a 0x6a3
#define MN_aaa 0x6a8
#define MN_daa 0x6ac
#define MN_ssca 0x6b0
#define MN_lea 0x6b5
#define MN_invlpga 0x6b9
#define MN_pusha 0x6c1
#define MN_ja 0x6c7
#define MN_jna 0x6ca
#define MN_ccmpna 0x6ce
#define MN_setna 0x6d5
#define MN_ctestna 0x6db
#define MN_setzuna 0x6e3
#define MN_cmovna (MN_fcmovna + 1)
#define MN_fcmovna (MN_cfcmovna + 1)
#define MN_cfcmovna 0x6eb
#define MN_ccmpa 0x6f4
#define MN_popa 0x6fa
#define MN_movntdqa (MN_vmovntdqa + 1)
#define MN_vmovntdqa 0x6ff
#define MN_movdqa (MN_vmovdqa + 1)
#define MN_vmovdqa 0x709
#define MN_seta 0x711
#define MN_prefetchnta 0x716
#define MN_ctesta 0x722
#define MN_setzua 0x729
#define MN_cmova (MN_fcmova + 1)
#define MN_fcmova (MN_cfcmova + 1)
#define MN_cfcmova 0x730
#define MN_rex_b 0x738
#define MN_ud2b 0x73e
#define MN_vpermi2b 0x743
#define MN_vpmovm2b 0x74c
#define MN_vpermt2b 0x755
#define MN_movdir64b 0x75e
#define MN_cmpxchg16b 0x768
#define MN_cmpxchg8b 0x773
#define MN_vpshab 0x77d
#define MN_sbb 0x784
#define MN_psubb (MN_vpsubb + 1)
#define MN_vpsubb 0x788
#define MN_xcrypt_ecb 0x78f
#define MN_xcryptecb 0x79a
#define MN_llwpcb 0x7a4
#define MN_slwpcb 0x7ab
#define MN_kaddb 0x7b2
#define MN_paddb (MN_vpaddb + 1)
#define MN_vpaddb 0x7b8
#define MN_kandb 0x7bf
#define MN_vpexpandb 0x7c5
#define MN_vpmovusdb 0x7cf
#define MN_vpmovsdb 0x7d9
#define MN_udb 0x7e2
#define MN_vpmovdb 0x7e6
#define MN_vpcomgeb 0x7ee
#define MN_vpcomleb 0x7f7
#define MN_vpcmpnleb 0x800
#define MN_vpcmpleb 0x80a
#define MN_vpcomfalseb 0x813
#define MN_vpcomtrueb 0x81f
#define MN_xcrypt_cfb 0x82a
#define MN_xcryptcfb 0x835
#define MN_xcrypt_ofb 0x83f
#define MN_xcryptofb 0x84a
#define MN_pshufb (MN_vpshufb + 1)
#define MN_vpshufb 0x854
#define MN_invlpgb 0x85c
#define MN_pavgb (MN_vpavgb + 1)
#define MN_vpavgb 0x864
#define MN_jb 0x86b
#define MN_pbndkb 0x86e
#define MN_pmovmskb (MN_vpmovmskb + 1)
#define MN_vpmovmskb 0x875
#define MN_vpshlb 0x87f
#define MN_kshiftlb 0x886
#define MN_gf2p8mulb (MN_vgf2p8mulb + 1)
#define MN_vgf2p8mulb 0x88f
#define MN_vpblendmb 0x89a
#define MN_vptestnmb 0x8a4
#define MN_vpcomb 0x8ae
#define MN_vpshufbitqmb 0x8b5
#define MN_vpermb 0x8c2
#define MN_vptestmb 0x8c9
#define MN_kandnb 0x8d2
#define MN_psignb (MN_vpsignb + 1)
#define MN_vpsignb 0x8d9
#define MN_jnb 0x8e1
#define MN_ccmpnb 0x8e5
#define MN_setnb 0x8ec
#define MN_ctestnb 0x8f2
#define MN_setzunb 0x8fa
#define MN_cmovnb (MN_fcmovnb + 1)
#define MN_fcmovnb (MN_cfcmovnb + 1)
#define MN_cfcmovnb 0x902
#define MN_ccmpb 0x90b
#define MN_vpcmpb 0x911
#define MN_vpcomeqb 0x918
#define MN_gf2p8affineqb (MN_vgf2p8affineqb + 1)
#define MN_vgf2p8affineqb 0x921
#define MN_vpcomneqb 0x930
#define MN_vpcmpneqb 0x93a
#define MN_pcmpeqb (MN_vpcmpeqb + 1)
#define MN_vpcmpeqb 0x944
#define MN_vpmovusqb 0x94d
#define MN_vpmovsqb 0x957
#define MN_vpmultishiftqb 0x960
#define MN_gf2p8affineinvqb (MN_vgf2p8affineinvqb + 1)
#define MN_vgf2p8affineinvqb 0x96f
#define MN_vpmovqb 0x981
#define MN_rex_rb 0x989
#define MN_korb 0x990
#define MN_kxnorb 0x995
#define MN_kxorb 0x99c
#define MN_pinsrb (MN_vpinsrb + 1)
#define MN_vpinsrb 0x9a2
#define MN_kshiftrb 0x9aa
#define MN_pextrb (MN_vpextrb + 1)
#define MN_vpextrb 0x9b3
#define MN_rex_wrb 0x9bb
#define MN_pabsb (MN_vpabsb + 1)
#define MN_vpabsb 0x9c3
#define MN_psubsb (MN_vpsubsb + 1)
#define MN_vpsubsb 0x9ca
#define MN_paddsb (MN_vpaddsb + 1)
#define MN_vpaddsb 0x9d2
#define MN_pminsb (MN_vpminsb + 1)
#define MN_vpminsb 0x9da
#define MN_vmovrsb 0x9e2
#define MN_vpcompressb 0x9ea
#define MN_psubusb (MN_vpsubusb + 1)
#define MN_vpsubusb 0x9f6
#define MN_paddusb (MN_vpaddusb + 1)
#define MN_vpaddusb 0x9ff
#define MN_pavgusb 0xa08
#define MN_movsb 0xa10
#define MN_pmaxsb (MN_vpmaxsb + 1)
#define MN_vpmaxsb 0xa16
#define MN_setb 0xa1e
#define MN_vpcomgtb 0xa23
#define MN_pcmpgtb (MN_vpcmpgtb + 1)
#define MN_vpcmpgtb 0xa2c
#define MN_vpcomltb 0xa35
#define MN_vpcmpnltb 0xa3e
#define MN_vpcmpltb 0xa48
#define MN_vpopcntb 0xa51
#define MN_knotb 0xa5a
#define MN_vprotb 0xa60
#define MN_vpbroadcastb 0xa67
#define MN_ctestb 0xa74
#define MN_ktestb 0xa7b
#define MN_kortestb 0xa82
#define MN_vpcomgeub 0xa8b
#define MN_vpcomleub 0xa95
#define MN_vpcmpnleub 0xa9f
#define MN_vpcmpleub 0xaaa
#define MN_vpcomfalseub 0xab4
#define MN_vpcomtrueub 0xac1
#define MN_vpcomub 0xacd
#define MN_pminub (MN_vpminub + 1)
#define MN_vpminub 0xad5
#define MN_vpcmpub 0xadd
#define MN_vpcomequb 0xae5
#define MN_vpcomnequb 0xaef
#define MN_vpcmpnequb 0xafa
#define MN_vpcmpequb 0xb05
#define MN_sub (MN_fsub + 1)
#define MN_fsub (MN_pfsub + 1)
#define MN_pfsub 0xb0f
#define MN_fisub 0xb15
#define MN_vpcomgtub 0xb1b
#define MN_vpcomltub 0xb25
#define MN_vpcmpnltub 0xb2f
#define MN_vpcmpltub 0xb3a
#define MN_pmaxub (MN_vpmaxub + 1)
#define MN_vpmaxub 0xb44
#define MN_setzub 0xb4c
#define MN_pblendvb (MN_vpblendvb + 1)
#define MN_vpblendvb 0xb53
#define MN_cmovb (MN_fcmovb + 1)
#define MN_fcmovb (MN_cfcmovb + 1)
#define MN_cfcmovb 0xb5d
#define MN_kmovb 0xb65
#define MN_rex_wb 0xb6b
#define MN_clwb 0xb72
#define MN_packsswb (MN_vpacksswb + 1)
#define MN_vpacksswb 0xb77
#define MN_packuswb (MN_vpackuswb + 1)
#define MN_vpackuswb 0xb81
#define MN_vpmovuswb 0xb8b
#define MN_vpmovswb 0xb95
#define MN_vpmovwb 0xb9e
#define MN_rex_xb 0xba6
#define MN_rex_rxb 0xbad
#define MN_rex_wrxb 0xbb5
#define MN_rex_wxb 0xbbe
#define MN_movzb 0xbc6
#define MN_clac 0xbcc
#define MN_stac 0xbd1
#define MN_xcrypt_cbc 0xbd6
#define MN_xcryptcbc 0xbe1
#define MN_pfacc 0xbeb
#define MN_pfnacc 0xbf1
#define MN_pfpnacc 0xbf8
#define MN_adc 0xc00
#define MN_dec (MN_aesdec + 3)
#define MN_aesdec (MN_vaesdec + 1)
#define MN_vaesdec 0xc04
#define MN_getsec 0xc0c
#define MN_xsavec 0xc13
#define MN_blcic 0xc1a
#define MN_blsic 0xc20
#define MN_jc 0xc26
#define MN_t1mskc 0xc29
#define MN_clc 0xc30
#define MN_cmc 0xc34
#define MN_aesimc (MN_vaesimc + 1)
#define MN_vaesimc 0xc38
#define MN_rdpmc 0xc40
#define MN_aesenc (MN_vaesenc + 1)
#define MN_vaesenc 0xc46
#define MN_inc 0xc4e
#define MN_jnc 0xc52
#define MN_ccmpnc 0xc56
#define MN_setnc 0xc5d
#define MN_ctestnc 0xc63
#define MN_vmfunc 0xc6b
#define MN_setzunc 0xc72
#define MN_cmovnc (MN_cfcmovnc + 2)
#define MN_cfcmovnc 0xc7a
#define MN_tlbsync 0xc83
#define MN_ccmpc 0xc8b
#define MN_rdtsc 0xc91
#define MN_btc 0xc97
#define MN_setc 0xc9b
#define MN_stc (MN_ctestc + 3)
#define MN_ctestc 0xca0
#define MN_setzuc 0xca7
#define MN_cmovc (MN_cfcmovc + 2)
#define MN_cfcmovc 0xcae
#define MN_vpermi2d 0xcb6
#define MN_vpmovm2d 0xcbf
#define MN_vpermt2d 0xcc8
#define MN_vpbroadcastmw2d 0xcd1
#define MN_aad 0xce1
#define MN_vmread 0xce5
#define MN_rmpread 0xcec
#define MN_vpshad 0xcf4
#define MN_vmload 0xcfb
#define MN_psrad (MN_vpsrad + 1)
#define MN_vpsrad 0xd02
#define MN_vphaddbd 0xd09
#define MN_vphaddubd 0xd12
#define MN_phsubd (MN_vphsubd + 1)
#define MN_vphsubd 0xd1c
#define MN_psubd (MN_vpsubd + 1)
#define MN_vpsubd 0xd24
#define MN_pmovsxbd (MN_vpmovsxbd + 1)
#define MN_vpmovsxbd 0xd2b
#define MN_pmovzxbd (MN_vpmovzxbd + 1)
#define MN_vpmovzxbd 0xd35
#define MN_add (MN_aadd + 1)
#define MN_aadd 0xd3f
#define MN_fadd (MN_pfadd + 1)
#define MN_pfadd 0xd44
#define MN_fiadd 0xd4a
#define MN_tileloadd 0xd50
#define MN_xadd (MN_cmpnaxadd + 5)
#define MN_cmpnaxadd 0xd5a
#define MN_cmpaxadd 0xd64
#define MN_cmpnbxadd 0xd6d
#define MN_cmpbxadd 0xd77
#define MN_cmpncxadd 0xd80
#define MN_cmpcxadd 0xd8a
#define MN_cmpnaexadd 0xd93
#define MN_cmpaexadd 0xd9e
#define MN_cmpnbexadd 0xda8
#define MN_cmpbexadd 0xdb3
#define MN_cmpngexadd 0xdbd
#define MN_cmpgexadd 0xdc8
#define MN_cmpnlexadd 0xdd2
#define MN_cmplexadd 0xddd
#define MN_cmpnexadd 0xde7
#define MN_cmpexadd 0xdf1
#define MN_cmppexadd 0xdfa
#define MN_cmpngxadd 0xe04
#define MN_cmpgxadd 0xe0e
#define MN_cmpnlxadd 0xe17
#define MN_cmplxadd 0xe21
#define MN_cmpnoxadd 0xe2a
#define MN_cmpoxadd 0xe34
#define MN_cmppoxadd 0xe3d
#define MN_cmpnpxadd 0xe47
#define MN_cmppxadd 0xe51
#define MN_cmpnsxadd 0xe5a
#define MN_cmpsxadd 0xe64
#define MN_cmpnzxadd 0xe6d
#define MN_cmpzxadd 0xe77
#define MN_phaddd (MN_vphaddd + 1)
#define MN_vphaddd 0xe80
#define MN_kaddd 0xe88
#define MN_paddd (MN_vpaddd + 1)
#define MN_vpaddd 0xe8e
#define MN_vpshldd 0xe95
#define MN_kandd 0xe9d
#define MN_vpandd 0xea3
#define MN_vpexpandd 0xeaa
#define MN_vpblendd 0xeb4
#define MN_vpgatherdd 0xebd
#define MN_vpscatterdd 0xec8
#define MN_vpshrdd 0xed4
#define MN_vpmacsdd 0xedc
#define MN_vpmacssdd 0xee5
#define MN_rdseed 0xeef
#define MN_vpcomged 0xef6
#define MN_vpcomled 0xeff
#define MN_vpcmpnled 0xf08
#define MN_vpcmpled 0xf12
#define MN_tilestored 0xf1b
#define MN_vpcomfalsed 0xf26
#define MN_ttransposed 0xf32
#define MN_vpcomtrued 0xf3e
#define MN_pi2fd 0xf49
#define MN_pshufd (MN_vpshufd + 1)
#define MN_vpshufd 0xf4f
#define MN_vpternlogd 0xf57
#define MN_pf2id 0xf62
#define MN_invpcid 0xf68
#define MN_rdpid 0xf70
#define MN_invvpid 0xf76
#define MN_cpuid 0xf7e
#define MN_fbld 0xf84
#define MN_cld 0xf89
#define MN_fld 0xf8d
#define MN_shld (MN_vpshld + 2)
#define MN_vpshld 0xf91
#define MN_fild 0xf98
#define MN_pslld (MN_vpslld + 1)
#define MN_vpslld 0xf9d
#define MN_pmulld (MN_vpmulld + 1)
#define MN_vpmulld 0xfa4
#define MN_vprold 0xfac
#define MN_psrld (MN_vpsrld + 1)
#define MN_vpsrld 0xfb3
#define MN_vmptrld 0xfba
#define MN_kshiftld 0xfc2
#define MN_enqcmd 0xfcb
#define MN_vpblendmd 0xfd2
#define MN_vptestnmd 0xfdc
#define MN_vpcomd 0xfe6
#define MN_vpermd 0xfed
#define MN_vptestmd 0xff4
#define MN_and (MN_aand + 1)
#define MN_aand 0xffd
#define MN_pand (MN_vpand + 1)
#define MN_vpand 0x1002
#define MN_rdrand 0x1008
#define MN_bnd 0x100f
#define MN_kandnd 0x1013
#define MN_vpandnd 0x101a
#define MN_xend 0x1022
#define MN_valignd 0x1027
#define MN_psignd (MN_vpsignd + 1)
#define MN_vpsignd 0x102f
#define MN_bound 0x1037
#define MN_slod 0x103d
#define MN_vfmaddsub231pd 0x1042
#define MN_vfmsub231pd 0x1051
#define MN_vfnmsub231pd 0x105d
#define MN_vfmsubadd231pd 0x106a
#define MN_vfmadd231pd 0x1079
#define MN_vfnmadd231pd 0x1085
#define MN_vfmaddsub132pd 0x1092
#define MN_vfmsub132pd 0x10a1
#define MN_vfnmsub132pd 0x10ad
#define MN_vfmsubadd132pd 0x10ba
#define MN_vfmadd132pd 0x10c9
#define MN_vfnmadd132pd 0x10d5
#define MN_vcvtph2pd 0x10e2
#define MN_vpermi2pd 0x10ec
#define MN_cvtpi2pd 0x10f6
#define MN_vpermil2pd 0x10ff
#define MN_vexp2pd 0x110a
#define MN_cvtdq2pd (MN_vcvtdq2pd + 1)
#define MN_vcvtdq2pd 0x1112
#define MN_vcvtudq2pd 0x111c
#define MN_vcvtqq2pd 0x1127
#define MN_vcvtuqq2pd 0x1131
#define MN_cvtps2pd (MN_vcvtps2pd + 1)
#define MN_vcvtps2pd 0x113c
#define MN_vpermt2pd 0x1146
#define MN_vfmaddsub213pd 0x1150
#define MN_vfmsub213pd 0x115f
#define MN_vfnmsub213pd 0x116b
#define MN_vfmsubadd213pd 0x1178
#define MN_vfmadd213pd 0x1187
#define MN_vfnmadd213pd 0x1193
#define MN_vrcp14pd 0x11a0
#define MN_vrsqrt14pd 0x11a9
#define MN_vrcp28pd 0x11b4
#define MN_vrsqrt28pd 0x11bd
#define MN_movapd (MN_vmovapd + 1)
#define MN_vmovapd 0x11c8
#define MN_pswapd 0x11d0
#define MN_subpd (MN_addsubpd + 3)
#define MN_addsubpd (MN_vfmaddsubpd + 3)
#define MN_vfmaddsubpd 0x11d7
#define MN_vaddsubpd 0x11e3
#define MN_hsubpd (MN_vhsubpd + 1)
#define MN_vhsubpd 0x11ed
#define MN_vfmsubpd 0x11f5
#define MN_vfnmsubpd 0x11fe
#define MN_vsubpd 0x1208
#define MN_vgatherpf0dpd 0x120f
#define MN_vscatterpf0dpd 0x121d
#define MN_vgatherpf1dpd 0x122c
#define MN_vscatterpf1dpd 0x123a
#define MN_addpd (MN_vfmsubaddpd + 6)
#define MN_vfmsubaddpd 0x1249
#define MN_haddpd (MN_vhaddpd + 1)
#define MN_vhaddpd 0x1255
#define MN_vfmaddpd 0x125d
#define MN_vfnmaddpd 0x1266
#define MN_vaddpd 0x1270
#define MN_andpd (MN_vexpandpd + 4)
#define MN_vexpandpd 0x1277
#define MN_vandpd 0x1281
#define MN_blendpd (MN_vblendpd + 1)
#define MN_vblendpd 0x1288
#define MN_roundpd (MN_vroundpd + 1)
#define MN_vroundpd 0x1291
#define MN_vgatherdpd 0x129a
#define MN_vscatterdpd 0x12a5
#define MN_cmpunordpd (MN_vcmpunordpd + 1)
#define MN_vcmpunordpd 0x12b1
#define MN_cmpordpd (MN_vcmpordpd + 1)
#define MN_vcmpordpd 0x12bd
#define MN_vreducepd 0x12c7
#define MN_vrangepd 0x12d1
#define MN_vcmpngepd 0x12da
#define MN_vcmpgepd 0x12e4
#define MN_vrndscalepd 0x12ed
#define MN_cmpnlepd (MN_vcmpnlepd + 1)
#define MN_vcmpnlepd 0x12f9
#define MN_cmplepd (MN_vcmplepd + 1)
#define MN_vcmplepd 0x1303
#define MN_vcmpfalsepd 0x130c
#define MN_vcmptruepd 0x1318
#define MN_vscalefpd 0x1323
#define MN_shufpd (MN_vshufpd + 1)
#define MN_vshufpd 0x132d
#define MN_unpckhpd (MN_vunpckhpd + 1)
#define MN_vunpckhpd 0x1335
#define MN_movhpd (MN_vmovhpd + 1)
#define MN_vmovhpd 0x133f
#define MN_movmskpd (MN_vmovmskpd + 1)
#define MN_vmovmskpd 0x1347
#define MN_vpermilpd 0x1351
#define MN_unpcklpd (MN_vunpcklpd + 1)
#define MN_vunpcklpd 0x135b
#define MN_mulpd (MN_vmulpd + 1)
#define MN_vmulpd 0x1365
#define MN_movlpd (MN_vmovlpd + 1)
#define MN_vmovlpd 0x136c
#define MN_vpcmpd 0x1374
#define MN_vblendmpd 0x137b
#define MN_vfixupimmpd 0x1385
#define MN_vpermpd 0x1391
#define MN_andnpd (MN_vandnpd + 1)
#define MN_vandnpd 0x1399
#define MN_minpd (MN_vminpd + 1)
#define MN_vminpd 0x13a1
#define MN_dppd (MN_vdppd + 1)
#define MN_vdppd 0x13a8
#define MN_cmppd (MN_vcmppd + 1)
#define MN_vcmppd 0x13ae
#define MN_vgetexppd 0x13b5
#define MN_vgatherpf0qpd 0x13bf
#define MN_vscatterpf0qpd 0x13cd
#define MN_vgatherpf1qpd 0x13dc
#define MN_vscatterpf1qpd 0x13ea
#define MN_vcmpunord_qpd 0x13f9
#define MN_vcmpord_qpd 0x1407
#define MN_cmpneqpd (MN_vcmpneqpd + 1)
#define MN_vcmpneqpd 0x1413
#define MN_cmpeqpd (MN_vcmpeqpd + 1)
#define MN_vcmpeqpd 0x141d
#define MN_vcmpge_oqpd 0x1426
#define MN_vcmple_oqpd 0x1432
#define MN_vcmpfalse_oqpd 0x143e
#define MN_vcmpneq_oqpd 0x144d
#define MN_vcmpeq_oqpd 0x145a
#define MN_vcmpgt_oqpd 0x1466
#define MN_vcmplt_oqpd 0x1472
#define MN_vgatherqpd 0x147e
#define MN_vscatterqpd 0x1489
#define MN_vcmpnge_uqpd 0x1495
#define MN_vcmpnle_uqpd 0x14a2
#define MN_vcmptrue_uqpd 0x14af
#define MN_vcmpneq_uqpd 0x14bd
#define MN_vcmpeq_uqpd 0x14ca
#define MN_vcmpngt_uqpd 0x14d6
#define MN_vcmpnlt_uqpd 0x14e3
#define MN_orpd (MN_vorpd + 1)
#define MN_vorpd 0x14f0
#define MN_xorpd (MN_vxorpd + 1)
#define MN_vxorpd 0x14f6
#define MN_vcmpunord_spd 0x14fd
#define MN_vcmpord_spd 0x150b
#define MN_vcmpge_ospd 0x1517
#define MN_vcmple_ospd 0x1523
#define MN_vcmpfalse_ospd 0x152f
#define MN_vcmpneq_ospd 0x153e
#define MN_vcmpeq_ospd 0x154b
#define MN_vcmpgt_ospd 0x1557
#define MN_vcmplt_ospd 0x1563
#define MN_vfpclasspd 0x156f
#define MN_incsspd 0x157a
#define MN_rdsspd 0x1582
#define MN_vcompresspd 0x1589
#define MN_vcmpnge_uspd 0x1595
#define MN_vcmpnle_uspd 0x15a2
#define MN_vcmptrue_uspd 0x15af
#define MN_vcmpneq_uspd 0x15bd
#define MN_vcmpeq_uspd 0x15ca
#define MN_vcmpngt_uspd 0x15d6
#define MN_vcmpnlt_uspd 0x15e3
#define MN_vcmpngtpd 0x15f0
#define MN_vcmpgtpd 0x15fa
#define MN_cmpnltpd (MN_vcmpnltpd + 1)
#define MN_vcmpnltpd 0x1603
#define MN_cmpltpd (MN_vcmpltpd + 1)
#define MN_vcmpltpd 0x160d
#define MN_vgetmantpd 0x1616
#define MN_movntpd (MN_vmovntpd + 1)
#define MN_vmovntpd 0x1621
#define MN_sqrtpd (MN_vsqrtpd + 1)
#define MN_vsqrtpd 0x162a
#define MN_vtestpd 0x1632
#define MN_movupd (MN_vmovupd + 1)
#define MN_vmovupd 0x163a
#define MN_blendvpd (MN_vblendvpd + 1)
#define MN_vblendvpd 0x1642
#define MN_divpd (MN_vdivpd + 1)
#define MN_vdivpd 0x164c
#define MN_vmaskmovpd 0x1653
#define MN_maxpd (MN_vminmaxpd + 4)
#define MN_vminmaxpd 0x165e
#define MN_vmaxpd 0x1668
#define MN_vfrczpd 0x166f
#define MN_vpcomeqd 0x1677
#define MN_vpcomneqd 0x1680
#define MN_vpcmpneqd 0x168a
#define MN_pcmpeqd (MN_vpcmpeqd + 1)
#define MN_vpcmpeqd 0x1694
#define MN_vpgatherqd 0x169d
#define MN_vpscatterqd 0x16a8
#define MN_vpmovusqd 0x16b4
#define MN_vpmovsqd 0x16be
#define MN_vpmovqd 0x16c7
#define MN_shrd 0x16cf
#define MN_kord 0x16d4
#define MN_kxnord 0x16d9
#define MN_vpord 0x16e0
#define MN_vprord 0x16e6
#define MN_word (MN_aword + 1)
#define MN_aword 0x16ed
#define MN_dword (MN_adword + 1)
#define MN_adword 0x16f3
#define MN_kxord 0x16fa
#define MN_vpxord 0x1700
#define MN_pinsrd (MN_vpinsrd + 1)
#define MN_vpinsrd 0x1707
#define MN_kshiftrd 0x170f
#define MN_pextrd (MN_vpextrd + 1)
#define MN_vpextrd 0x1718
#define MN_vfmsub231sd 0x1720
#define MN_vfnmsub231sd 0x172c
#define MN_vfmadd231sd 0x1739
#define MN_vfnmadd231sd 0x1745
#define MN_vfmsub132sd 0x1752
#define MN_vfnmsub132sd 0x175e
#define MN_vfmadd132sd 0x176b
#define MN_vfnmadd132sd 0x1777
#define MN_vcvtsh2sd 0x1784
#define MN_cvtsi2sd (MN_vcvtsi2sd + 1)
#define MN_vcvtsi2sd 0x178e
#define MN_vcvtusi2sd 0x1798
#define MN_cvtss2sd (MN_vcvtss2sd + 1)
#define MN_vcvtss2sd 0x17a3
#define MN_vfmsub213sd 0x17ad
#define MN_vfnmsub213sd 0x17b9
#define MN_vfmadd213sd 0x17c6
#define MN_vfnmadd213sd 0x17d2
#define MN_vrcp14sd 0x17df
#define MN_vrsqrt14sd 0x17e8
#define MN_vrcp28sd 0x17f3
#define MN_vrsqrt28sd 0x17fc
#define MN_pabsd (MN_vpabsd + 1)
#define MN_vpabsd 0x1807
#define MN_subsd (MN_vfmsubsd + 3)
#define MN_vfmsubsd 0x180e
#define MN_vfnmsubsd 0x1817
#define MN_vsubsd 0x1821
#define MN_addsd (MN_vfmaddsd + 3)
#define MN_vfmaddsd 0x1828
#define MN_vfnmaddsd 0x1831
#define MN_vaddsd 0x183b
#define MN_roundsd (MN_vroundsd + 1)
#define MN_vroundsd 0x1842
#define MN_cmpunordsd (MN_vcmpunordsd + 1)
#define MN_vcmpunordsd 0x184b
#define MN_cmpordsd (MN_vcmpordsd + 1)
#define MN_vcmpordsd 0x1857
#define MN_vreducesd 0x1861
#define MN_vrangesd 0x186b
#define MN_vcmpngesd 0x1874
#define MN_vcmpgesd 0x187e
#define MN_vrndscalesd 0x1887
#define MN_cmpnlesd (MN_vcmpnlesd + 1)
#define MN_vcmpnlesd 0x1893
#define MN_cmplesd (MN_vcmplesd + 1)
#define MN_vcmplesd 0x189d
#define MN_vcmpfalsesd 0x18a6
#define MN_vcmptruesd 0x18b2
#define MN_vscalefsd 0x18bd
#define MN_comisd (MN_ucomisd + 1)
#define MN_ucomisd (MN_vucomisd + 1)
#define MN_vucomisd 0x18c7
#define MN_vcomisd 0x18d0
#define MN_mulsd (MN_vmulsd + 1)
#define MN_vmulsd 0x18d8
#define MN_vfixupimmsd 0x18df
#define MN_minsd (MN_pminsd + 1)
#define MN_pminsd (MN_vpminsd + 1)
#define MN_vpminsd 0x18eb
#define MN_vminsd 0x18f3
#define MN_cmpsd (MN_vcmpsd + 1)
#define MN_vcmpsd 0x18fa
#define MN_vgetexpsd 0x1901
#define MN_vcmpunord_qsd 0x190b
#define MN_vcmpord_qsd 0x1919
#define MN_cmpneqsd (MN_vcmpneqsd + 1)
#define MN_vcmpneqsd 0x1925
#define MN_cmpeqsd (MN_vcmpeqsd + 1)
#define MN_vcmpeqsd 0x192f
#define MN_vcmpge_oqsd 0x1938
#define MN_vcmple_oqsd 0x1944
#define MN_vcmpfalse_oqsd 0x1950
#define MN_vcmpneq_oqsd 0x195f
#define MN_vcmpeq_oqsd 0x196c
#define MN_vcmpgt_oqsd 0x1978
#define MN_vcmplt_oqsd 0x1984
#define MN_vcmpnge_uqsd 0x1990
#define MN_vcmpnle_uqsd 0x199d
#define MN_vcmptrue_uqsd 0x19aa
#define MN_vcmpneq_uqsd 0x19b8
#define MN_vcmpeq_uqsd 0x19c5
#define MN_vcmpngt_uqsd 0x19d1
#define MN_vcmpnlt_uqsd 0x19de
#define MN_vmovrsd 0x19eb
#define MN_vcmpunord_ssd 0x19f3
#define MN_vcmpord_ssd 0x1a01
#define MN_vpdpbssd 0x1a0d
#define MN_tdpbssd 0x1a16
#define MN_vpcompressd 0x1a1e
#define MN_vcmpge_ossd 0x1a2a
#define MN_vcmple_ossd 0x1a36
#define MN_vcmpfalse_ossd 0x1a42
#define MN_vcmpneq_ossd 0x1a51
#define MN_vcmpeq_ossd 0x1a5e
#define MN_vcmpgt_ossd 0x1a6a
#define MN_vcmplt_ossd 0x1a76
#define MN_wrssd 0x1a82
#define MN_vfpclasssd 0x1a88
#define MN_vcmpnge_ussd 0x1a93
#define MN_vcmpnle_ussd 0x1aa0
#define MN_vcmptrue_ussd 0x1aad
#define MN_vcmpneq_ussd 0x1abb
#define MN_vcmpeq_ussd 0x1ac8
#define MN_vcmpngt_ussd 0x1ad4
#define MN_vcmpnlt_ussd 0x1ae1
#define MN_wrussd 0x1aee
#define MN_vp4dpwssd 0x1af5
#define MN_vpdpwssd 0x1aff
#define MN_vcmpngtsd 0x1b08
#define MN_vcmpgtsd 0x1b12
#define MN_cmpnltsd (MN_vcmpnltsd + 1)
#define MN_vcmpnltsd 0x1b1b
#define MN_cmpltsd (MN_vcmpltsd + 1)
#define MN_vcmpltsd 0x1b25
#define MN_vgetmantsd 0x1b2e
#define MN_movntsd 0x1b39
#define MN_sqrtsd (MN_vsqrtsd + 1)
#define MN_vsqrtsd 0x1b41
#define MN_vbroadcastsd 0x1b49
#define MN_vpdpbusd 0x1b56
#define MN_tdpbusd 0x1b5f
#define MN_vpdpwusd 0x1b67
#define MN_divsd (MN_vdivsd + 1)
#define MN_vdivsd 0x1b70
#define MN_movsd (MN_vmovsd + 1)
#define MN_vmovsd 0x1b77
#define MN_maxsd (MN_vminmaxsd + 4)
#define MN_vminmaxsd 0x1b7e
#define MN_pmaxsd (MN_vpmaxsd + 1)
#define MN_vpmaxsd 0x1b88
#define MN_vmaxsd 0x1b90
#define MN_vucomxsd 0x1b97
#define MN_vcomxsd 0x1ba0
#define MN_vfrczsd 0x1ba8
#define MN_vp2intersectd 0x1bb0
#define MN_vpconflictd 0x1bbe
#define MN_vpcomgtd 0x1bca
#define MN_pcmpgtd (MN_vpcmpgtd + 1)
#define MN_vpcmpgtd 0x1bd3
#define MN_cltd 0x1bdc
#define MN_vpcomltd 0x1be1
#define MN_vpcmpnltd 0x1bea
#define MN_vpcmpltd 0x1bf4
#define MN_vpopcntd 0x1bfd
#define MN_vplzcntd 0x1c06
#define MN_knotd 0x1c0f
#define MN_vprotd 0x1c15
#define MN_std (MN_vpbroadcastd + 9)
#define MN_vpbroadcastd 0x1c1c
#define MN_ktestd 0x1c29
#define MN_kortestd 0x1c30
#define MN_cwtd 0x1c39
#define MN_vpcomgeud 0x1c3e
#define MN_vpcomleud 0x1c48
#define MN_vpcmpnleud 0x1c52
#define MN_vpcmpleud 0x1c5d
#define MN_vpcomfalseud 0x1c67
#define MN_vpcomtrueud 0x1c74
#define MN_vpcomud 0x1c80
#define MN_pminud (MN_vpminud + 1)
#define MN_vpminud 0x1c88
#define MN_vpcmpud 0x1c90
#define MN_vpcomequd 0x1c98
#define MN_vpcomnequd 0x1ca2
#define MN_vpcmpnequd 0x1cad
#define MN_vpcmpequd 0x1cb8
#define MN_vpdpbsud 0x1cc2
#define MN_tdpbsud 0x1ccb
#define MN_vpdpwsud 0x1cd3
#define MN_vpcomgtud 0x1cdc
#define MN_vpcomltud 0x1ce6
#define MN_vpcmpnltud 0x1cf0
#define MN_vpcmpltud 0x1cfb
#define MN_vpdpbuud 0x1d05
#define MN_tdpbuud 0x1d0e
#define MN_vpdpwuud 0x1d16
#define MN_pmaxud (MN_vpmaxud + 1)
#define MN_vpmaxud 0x1d1f
#define MN_vpsravd 0x1d27
#define MN_vpshldvd 0x1d2f
#define MN_vpshrdvd 0x1d38
#define MN_vpsllvd 0x1d41
#define MN_vprolvd 0x1d49
#define MN_vpsrlvd 0x1d51
#define MN_invd (MN_wbinvd + 2)
#define MN_wbinvd 0x1d59
#define MN_wbnoinvd 0x1d60
#define MN_movd (MN_kmovd + 1)
#define MN_kmovd (MN_vpmaskmovd + 5)
#define MN_vpmaskmovd 0x1d69
#define MN_vmovd 0x1d74
#define MN_vprorvd 0x1d7a
#define MN_vphsubwd 0x1d82
#define MN_cwd 0x1d8b
#define MN_vphaddwd 0x1d8f
#define MN_pmaddwd (MN_vpmaddwd + 1)
#define MN_vpmaddwd 0x1d98
#define MN_punpckhwd (MN_vpunpckhwd + 1)
#define MN_vpunpckhwd 0x1da1
#define MN_kunpckwd 0x1dac
#define MN_punpcklwd (MN_vpunpcklwd + 1)
#define MN_vpunpcklwd 0x1db5
#define MN_vpmacswd 0x1dc0
#define MN_vpmadcswd 0x1dc9
#define MN_vpmacsswd 0x1dd3
#define MN_vpmadcsswd 0x1ddd
#define MN_vphadduwd 0x1de8
#define MN_pmovsxwd (MN_vpmovsxwd + 1)
#define MN_vpmovsxwd 0x1df2
#define MN_pmovzxwd (MN_vpmovzxwd + 1)
#define MN_vpmovzxwd 0x1dfc
#define MN_movsxd 0x1e06
#define MN_fldl2e 0x1e0d
#define MN_jae 0x1e14
#define MN_jnae 0x1e18
#define MN_ccmpnae 0x1e1d
#define MN_setnae 0x1e25
#define MN_ctestnae 0x1e2c
#define MN_setzunae 0x1e35
#define MN_cmovnae (MN_fcmovnae + 1)
#define MN_fcmovnae (MN_cfcmovnae + 1)
#define MN_cfcmovnae 0x1e3e
#define MN_ccmpae 0x1e48
#define MN_setae 0x1e4f
#define MN_ctestae 0x1e55
#define MN_setzuae 0x1e5d
#define MN_cmovae (MN_fcmovae + 1)
#define MN_fcmovae (MN_cfcmovae + 1)
#define MN_cfcmovae 0x1e65
#define MN_jbe 0x1e6e
#define MN_jnbe 0x1e72
#define MN_ccmpnbe 0x1e77
#define MN_setnbe 0x1e7f
#define MN_ctestnbe 0x1e86
#define MN_setzunbe 0x1e8f
#define MN_cmovnbe (MN_fcmovnbe + 1)
#define MN_fcmovnbe (MN_cfcmovnbe + 1)
#define MN_cfcmovnbe 0x1e98
#define MN_ccmpbe 0x1ea2
#define MN_setbe 0x1ea9
#define MN_ctestbe 0x1eaf
#define MN_setzube 0x1eb7
#define MN_movbe (MN_cmovbe + 1)
#define MN_cmovbe (MN_fcmovbe + 1)
#define MN_fcmovbe (MN_cfcmovbe + 1)
#define MN_cfcmovbe 0x1ebf
#define MN_lfence 0x1ec8
#define MN_mfence 0x1ecf
#define MN_sfence 0x1ed6
#define MN_cwde 0x1edd
#define MN_ffree 0x1ee2
#define MN_jge 0x1ee8
#define MN_jnge 0x1eec
#define MN_ccmpnge 0x1ef1
#define MN_setnge 0x1ef9
#define MN_ctestnge 0x1f00
#define MN_setzunge 0x1f09
#define MN_cmovnge (MN_cfcmovnge + 2)
#define MN_cfcmovnge 0x1f12
#define MN_ccmpge 0x1f1c
#define MN_pfcmpge 0x1f23
#define MN_setge 0x1f2b
#define MN_ctestge 0x1f31
#define MN_setzuge 0x1f39
#define MN_cmovge (MN_cfcmovge + 2)
#define MN_cfcmovge 0x1f41
#define MN_je 0x1f4a
#define MN_fscale 0x1f4d
#define MN_jle 0x1f54
#define MN_jnle 0x1f58
#define MN_ccmpnle 0x1f5d
#define MN_setnle 0x1f65
#define MN_ctestnle 0x1f6c
#define MN_setzunle 0x1f75
#define MN_cmovnle (MN_cfcmovnle + 2)
#define MN_cfcmovnle 0x1f7e
#define MN_ccmple 0x1f88
#define MN_setle 0x1f8f
#define MN_ctestle 0x1f95
#define MN_setzule 0x1f9d
#define MN_cmovle (MN_cfcmovle + 2)
#define MN_cfcmovle 0x1fa5
#define MN_vmresume 0x1fae
#define MN_jne 0x1fb7
#define MN_repne 0x1fbb
#define MN_ccmpne 0x1fc1
#define MN_loopne 0x1fc8
#define MN_setne 0x1fcf
#define MN_ctestne 0x1fd5
#define MN_setzune 0x1fdd
#define MN_cmovne (MN_fcmovne + 1)
#define MN_fcmovne (MN_cfcmovne + 1)
#define MN_cfcmovne 0x1fe5
#define MN_repe 0x1fee
#define MN_jpe 0x1ff3
#define MN_ccmpe 0x1ff7
#define MN_loope 0x1ffd
#define MN_setpe 0x2003
#define MN_setzupe 0x2009
#define MN_cmovpe (MN_cfcmovpe + 2)
#define MN_cfcmovpe 0x2011
#define MN_cdqe 0x201a
#define MN_xacquire 0x201f
#define MN_xstore 0x2028
#define MN_rdfsbase 0x202f
#define MN_wrfsbase 0x2038
#define MN_rdgsbase 0x2041
#define MN_wrgsbase 0x204a
#define MN_tilerelease 0x2053
#define MN_xrelease 0x205f
#define MN_pause (MN_tpause + 1)
#define MN_tpause 0x2068
#define MN_pvalidate 0x206f
#define MN_rmpupdate 0x2079
#define MN_sete 0x2083
#define MN_vmwrite 0x2088
#define MN_ptwrite 0x2090
#define MN_cldemote 0x2098
#define MN_cteste 0x20a1
#define MN_sha1nexte 0x20a8
#define MN_setzue 0x20b2
#define MN_leave 0x20b9
#define MN_fsave 0x20bf
#define MN_vmsave 0x20c5
#define MN_fnsave 0x20cc
#define MN_xsave (MN_fxsave + 1)
#define MN_fxsave 0x20d3
#define MN_cmove (MN_fcmove + 1)
#define MN_fcmove (MN_cfcmove + 1)
#define MN_cfcmove 0x20da
#define MN_serialize 0x20e2
#define MN_vmxoff 0x20ec
#define MN_lahf 0x20f3
#define MN_sahf 0x20f8
#define MN_pushf 0x20fd
#define MN_ccmpf 0x2103
#define MN_popf 0x2109
#define MN_bsf 0x210e
#define MN_retf 0x2112
#define MN_ctestf 0x2117
#define MN_neg 0x211e
#define MN_ldtilecfg 0x2122
#define MN_sttilecfg 0x212c
#define MN_xchg (MN_cmpxchg + 3)
#define MN_cmpxchg 0x2136
#define MN_pconfig 0x213e
#define MN_jg 0x2146
#define MN_jng 0x2149
#define MN_ccmpng 0x214d
#define MN_xstore_rng 0x2154
#define MN_xstorerng 0x215f
#define MN_setng 0x2169
#define MN_ctestng 0x216f
#define MN_setzung 0x2177
#define MN_cmovng (MN_cfcmovng + 2)
#define MN_cfcmovng 0x217f
#define MN_invlpg 0x2188
#define MN_ccmpg 0x218f
#define MN_setg 0x2195
#define MN_ctestg 0x219a
#define MN_setzug 0x21a1
#define MN_cmovg (MN_cfcmovg + 2)
#define MN_cfcmovg 0x21a8
#define MN_tcvtrowps2bf16h 0x21b0
#define MN_vmlaunch 0x21c0
#define MN_prefetch 0x21c9
#define MN_fxch 0x21d2
#define MN_tcvtrowps2phh 0x21d7
#define MN_vfmaddsub231ph 0x21e5
#define MN_vfmsub231ph 0x21f4
#define MN_vfnmsub231ph 0x2200
#define MN_vfmsubadd231ph 0x220d
#define MN_vfmadd231ph 0x221c
#define MN_vfnmadd231ph 0x2228
#define MN_vfmaddsub132ph 0x2235
#define MN_vfmsub132ph 0x2244
#define MN_vfnmsub132ph 0x2250
#define MN_vfmsubadd132ph 0x225d
#define MN_vfmadd132ph 0x226c
#define MN_vfnmadd132ph 0x2278
#define MN_vcvthf82ph 0x2285
#define MN_vcvtpd2ph 0x2290
#define MN_vcvtdq2ph 0x229a
#define MN_vcvtudq2ph 0x22a4
#define MN_vcvtqq2ph 0x22af
#define MN_vcvtuqq2ph 0x22b9
#define MN_vcvtps2ph 0x22c4
#define MN_vcvtw2ph 0x22ce
#define MN_vcvtuw2ph 0x22d7
#define MN_vfmaddsub213ph 0x22e1
#define MN_vfmsub213ph 0x22f0
#define MN_vfnmsub213ph 0x22fc
#define MN_vfmsubadd213ph 0x2309
#define MN_vfmadd213ph 0x2318
#define MN_vfnmadd213ph 0x2324
#define MN_vsubph 0x2331
#define MN_vfcmaddcph 0x2338
#define MN_vfmaddcph 0x2343
#define MN_vfcmulcph 0x234d
#define MN_vfmulcph 0x2357
#define MN_vaddph 0x2360
#define MN_vcmpunordph 0x2367
#define MN_vcmpordph 0x2373
#define MN_vreduceph 0x237d
#define MN_vcmpngeph 0x2387
#define MN_vcmpgeph 0x2391
#define MN_vrndscaleph 0x239a
#define MN_vcmpnleph 0x23a6
#define MN_vcmpleph 0x23b0
#define MN_vcmpfalseph 0x23b9
#define MN_vcmptrueph 0x23c5
#define MN_vscalefph 0x23d0
#define MN_vmulph 0x23da
#define MN_vminph 0x23e1
#define MN_vrcpph 0x23e8
#define MN_vcmpph 0x23ef
#define MN_vgetexpph 0x23f6
#define MN_vcmpunord_qph 0x2400
#define MN_vcmpord_qph 0x240e
#define MN_vcmpneqph 0x241a
#define MN_vcmpeqph 0x2424
#define MN_vcmpge_oqph 0x242d
#define MN_vcmple_oqph 0x2439
#define MN_vcmpfalse_oqph 0x2445
#define MN_vcmpneq_oqph 0x2454
#define MN_vcmpeq_oqph 0x2461
#define MN_vcmpgt_oqph 0x246d
#define MN_vcmplt_oqph 0x2479
#define MN_vcmpnge_uqph 0x2485
#define MN_vcmpnle_uqph 0x2492
#define MN_vcmptrue_uqph 0x249f
#define MN_vcmpneq_uqph 0x24ad
#define MN_vcmpeq_uqph 0x24ba
#define MN_vcmpngt_uqph 0x24c6
#define MN_vcmpnlt_uqph 0x24d3
#define MN_vcmpunord_sph 0x24e0
#define MN_vcmpord_sph 0x24ee
#define MN_vcmpge_osph 0x24fa
#define MN_vcmple_osph 0x2506
#define MN_vcmpfalse_osph 0x2512
#define MN_vcmpneq_osph 0x2521
#define MN_vcmpeq_osph 0x252e
#define MN_vcmpgt_osph 0x253a
#define MN_vcmplt_osph 0x2546
#define MN_vfpclassph 0x2552
#define MN_vcmpnge_usph 0x255d
#define MN_vcmpnle_usph 0x256a
#define MN_vcmptrue_usph 0x2577
#define MN_vcmpneq_usph 0x2585
#define MN_vcmpeq_usph 0x2592
#define MN_vcmpngt_usph 0x259e
#define MN_vcmpnlt_usph 0x25ab
#define MN_vcmpngtph 0x25b8
#define MN_vcmpgtph 0x25c2
#define MN_vcmpnltph 0x25cb
#define MN_vcmpltph 0x25d5
#define MN_vgetmantph 0x25de
#define MN_vrsqrtph 0x25e9
#define MN_vsqrtph 0x25f2
#define MN_vdivph 0x25fa
#define MN_vminmaxph 0x2601
#define MN_vmaxph 0x260b
#define MN_vpmacsdqh 0x2612
#define MN_vpmacssdqh 0x261c
#define MN_vfmsub231sh 0x2627
#define MN_vfnmsub231sh 0x2633
#define MN_vfmadd231sh 0x2640
#define MN_vfnmadd231sh 0x264c
#define MN_vfmsub132sh 0x2659
#define MN_vfnmsub132sh 0x2665
#define MN_vfmadd132sh 0x2672
#define MN_vfnmadd132sh 0x267e
#define MN_vcvtsd2sh 0x268b
#define MN_vcvtsi2sh 0x2695
#define MN_vcvtusi2sh 0x269f
#define MN_vcvtss2sh 0x26aa
#define MN_vfmsub213sh 0x26b4
#define MN_vfnmsub213sh 0x26c0
#define MN_vfmadd213sh 0x26cd
#define MN_vfnmadd213sh 0x26d9
#define MN_psmash 0x26e6
#define MN_vsubsh 0x26ed
#define MN_vfcmaddcsh 0x26f4
#define MN_vfmaddcsh 0x26ff
#define MN_vfcmulcsh 0x2709
#define MN_vfmulcsh 0x2713
#define MN_vaddsh 0x271c
#define MN_vcmpunordsh 0x2723
#define MN_vcmpordsh 0x272f
#define MN_vreducesh 0x2739
#define MN_vcmpngesh 0x2743
#define MN_vcmpgesh 0x274d
#define MN_vrndscalesh 0x2756
#define MN_vcmpnlesh 0x2762
#define MN_vcmplesh 0x276c
#define MN_vcmpfalsesh 0x2775
#define MN_vcmptruesh 0x2781
#define MN_vscalefsh 0x278c
#define MN_vucomish 0x2796
#define MN_vcomish 0x279f
#define MN_vmulsh 0x27a7
#define MN_vminsh 0x27ae
#define MN_vrcpsh 0x27b5
#define MN_vcmpsh 0x27bc
#define MN_vgetexpsh 0x27c3
#define MN_vcmpunord_qsh 0x27cd
#define MN_vcmpord_qsh 0x27db
#define MN_vcmpneqsh 0x27e7
#define MN_vcmpeqsh 0x27f1
#define MN_vcmpge_oqsh 0x27fa
#define MN_vcmple_oqsh 0x2806
#define MN_vcmpfalse_oqsh 0x2812
#define MN_vcmpneq_oqsh 0x2821
#define MN_vcmpeq_oqsh 0x282e
#define MN_vcmpgt_oqsh 0x283a
#define MN_vcmplt_oqsh 0x2846
#define MN_vcmpnge_uqsh 0x2852
#define MN_vcmpnle_uqsh 0x285f
#define MN_vcmptrue_uqsh 0x286c
#define MN_vcmpneq_uqsh 0x287a
#define MN_vcmpeq_uqsh 0x2887
#define MN_vcmpngt_uqsh 0x2893
#define MN_vcmpnlt_uqsh 0x28a0
#define MN_vcmpunord_ssh 0x28ad
#define MN_vcmpord_ssh 0x28bb
#define MN_vcmpge_ossh 0x28c7
#define MN_vcmple_ossh 0x28d3
#define MN_vcmpfalse_ossh 0x28df
#define MN_vcmpneq_ossh 0x28ee
#define MN_vcmpeq_ossh 0x28fb
#define MN_vcmpgt_ossh 0x2907
#define MN_vcmplt_ossh 0x2913
#define MN_vfpclasssh 0x291f
#define MN_vcmpnge_ussh 0x292a
#define MN_vcmpnle_ussh 0x2937
#define MN_vcmptrue_ussh 0x2944
#define MN_vcmpneq_ussh 0x2952
#define MN_vcmpeq_ussh 0x295f
#define MN_vcmpngt_ussh 0x296b
#define MN_vcmpnlt_ussh 0x2978
#define MN_vcmpngtsh 0x2985
#define MN_vcmpgtsh 0x298f
#define MN_vcmpnltsh 0x2998
#define MN_vcmpltsh 0x29a2
#define MN_vgetmantsh 0x29ab
#define MN_vrsqrtsh 0x29b6
#define MN_vsqrtsh 0x29bf
#define MN_clflush 0x29c7
#define MN_push 0x29cf
#define MN_vdivsh 0x29d4
#define MN_vmovsh 0x29db
#define MN_vminmaxsh 0x29e2
#define MN_vmaxsh 0x29ec
#define MN_vucomxsh 0x29f3
#define MN_vcomxsh 0x29fc
#define MN_blci 0x2a04
#define MN_clgi 0x2a09
#define MN_stgi 0x2a0e
#define MN_bzhi 0x2a13
#define MN_cli 0x2a18
#define MN_fcomi 0x2a1c
#define MN_fucomi 0x2a22
#define MN_feni 0x2a29
#define MN_fneni 0x2a2e
#define MN_cvttpd2pi 0x2a34
#define MN_cvtpd2pi 0x2a3e
#define MN_cvttps2pi 0x2a47
#define MN_cvtps2pi 0x2a51
#define MN_fldpi 0x2a5a
#define MN_senduipi 0x2a60
#define MN_fcompi 0x2a69
#define MN_fucompi 0x2a70
#define MN_movdiri 0x2a78
#define MN_pcmpestri (MN_vpcmpestri + 1)
#define MN_vpcmpestri 0x2a80
#define MN_pcmpistri (MN_vpcmpistri + 1)
#define MN_vpcmpistri 0x2a8b
#define MN_cvttsd2si (MN_vcvttsd2si + 1)
#define MN_vcvttsd2si 0x2a96
#define MN_cvtsd2si (MN_vcvtsd2si + 1)
#define MN_vcvtsd2si 0x2aa1
#define MN_vcvttsh2si 0x2aab
#define MN_vcvtsh2si 0x2ab6
#define MN_cvttss2si (MN_vcvttss2si + 1)
#define MN_vcvttss2si 0x2ac0
#define MN_cvtss2si (MN_vcvtss2si + 1)
#define MN_vcvtss2si 0x2acb
#define MN_fdisi 0x2ad5
#define MN_fndisi 0x2adb
#define MN_blsi 0x2ae2
#define MN_vcvttsd2usi 0x2ae7
#define MN_vcvtsd2usi 0x2af3
#define MN_vcvttsh2usi 0x2afe
#define MN_vcvtsh2usi 0x2b0a
#define MN_vcvttss2usi 0x2b15
#define MN_vcvtss2usi 0x2b21
#define MN_movnti 0x2b2c
#define MN_sti 0x2b33
#define MN_clui 0x2b37
#define MN_stui (MN_testui + 2)
#define MN_testui 0x2b3c
#define MN_notrack 0x2b43
#define MN_lock 0x2b4b
#define MN_bndmk 0x2b50
#define MN_xresldtrk 0x2b56
#define MN_xsusldtrk 0x2b60
#define MN_blcmsk 0x2b6a
#define MN_blsmsk 0x2b71
#define MN_tzmsk 0x2b78
#define MN_tcvtrowps2bf16l 0x2b7e
#define MN_sal 0x2b8e
#define MN_lwpval 0x2b92
#define MN_bndcl 0x2b99
#define MN_rcl 0x2b9f
#define MN_tcvtrowps2phl 0x2ba3
#define MN_shl 0x2bb1
#define MN_jl 0x2bb5
#define MN_aesdec256kl 0x2bb8
#define MN_aesenc256kl 0x2bc4
#define MN_aesdecwide256kl 0x2bd0
#define MN_aesencwide256kl 0x2be0
#define MN_aesdec128kl 0x2bf0
#define MN_aesenc128kl 0x2bfc
#define MN_aesdecwide128kl 0x2c08
#define MN_aesencwide128kl 0x2c18
#define MN_call (MN_tdcall + 2)
#define MN_tdcall 0x2c28
#define MN_lcall 0x2c2f
#define MN_seamcall 0x2c35
#define MN_vmmcall 0x2c3e
#define MN_vmcall 0x2c46
#define MN_syscall 0x2c4d
#define MN_vzeroall 0x2c55
#define MN_fildll 0x2c5e
#define MN_blcfill 0x2c65
#define MN_blsfill 0x2c6d
#define MN_fistpll 0x2c75
#define MN_fisttpll 0x2c7d
#define MN_jnl 0x2c86
#define MN_ccmpnl 0x2c8a
#define MN_setnl 0x2c91
#define MN_ctestnl 0x2c97
#define MN_setzunl 0x2c9f
#define MN_cmovnl (MN_cfcmovnl + 2)
#define MN_cfcmovnl 0x2ca7
#define MN_rol 0x2cb0
#define MN_ccmpl 0x2cb4
#define MN_arpl 0x2cba
#define MN_vpmacsdql 0x2cbf
#define MN_vpmacssdql 0x2cc9
#define MN_lsl 0x2cd4
#define MN_movsl 0x2cd8
#define MN_setl 0x2cde
#define MN_ctestl 0x2ce3
#define MN_cwtl 0x2cea
#define MN_mul (MN_fmul + 1)
#define MN_fmul (MN_pfmul + 1)
#define MN_pfmul 0x2cef
#define MN_imul (MN_fimul + 1)
#define MN_fimul 0x2cf5
#define MN_montmul 0x2cfb
#define MN_setzul 0x2d03
#define MN_cmovl (MN_cfcmovl + 2)
#define MN_cfcmovl 0x2d0a
#define MN_vpmovb2m 0x2d12
#define MN_vpmovd2m 0x2d1b
#define MN_vpmovq2m 0x2d24
#define MN_vpmovw2m 0x2d2d
#define MN_aam 0x2d36
#define MN_fxam 0x2d3a
#define MN_fprem 0x2d3f
#define MN_fcom 0x2d45
#define MN_ficom 0x2d4a
#define MN_fucom 0x2d50
#define MN_fsetpm 0x2d56
#define MN_fnsetpm 0x2d5d
#define MN_frstpm 0x2d65
#define MN_vpperm 0x2d6c
#define MN_pcmpestrm (MN_vpcmpestrm + 1)
#define MN_vpcmpestrm 0x2d73
#define MN_pcmpistrm (MN_vpcmpistrm + 1)
#define MN_vpcmpistrm 0x2d7e
#define MN_rsm 0x2d89
#define MN_fpatan 0x2d8d
#define MN_fptan 0x2d94
#define MN_bndcn 0x2d9a
#define MN_andn (MN_pandn + 1)
#define MN_pandn (MN_vpandn + 1)
#define MN_vpandn 0x2da0
#define MN_in (MN_xbegin + 4)
#define MN_xbegin 0x2da7
#define MN_pfmin 0x2dae
#define MN_fsin 0x2db4
#define MN_vmxon 0x2db9
#define MN_vmrun 0x2dbf
#define MN_jo 0x2dc5
#define MN_jno 0x2dc8
#define MN_ccmpno 0x2dcc
#define MN_setno 0x2dd3
#define MN_ctestno 0x2dd9
#define MN_setzuno 0x2de1
#define MN_cmovno (MN_cfcmovno + 2)
#define MN_cfcmovno 0x2de9
#define MN_jpo 0x2df2
#define MN_ccmpo 0x2df6
#define MN_setpo 0x2dfc
#define MN_setzupo 0x2e02
#define MN_cmovpo (MN_cfcmovpo + 2)
#define MN_cfcmovpo 0x2e0a
#define MN_cqo 0x2e13
#define MN_tilezero 0x2e17
#define MN_clzero 0x2e20
#define MN_seto 0x2e27
#define MN_into 0x2e2c
#define MN_cqto 0x2e31
#define MN_ctesto 0x2e36
#define MN_ssto 0x2e3d
#define MN_setzuo 0x2e42
#define MN_cmovo (MN_cfcmovo + 2)
#define MN_cfcmovo 0x2e49
#define MN_push2p 0x2e51
#define MN_pop2p 0x2e58
#define MN_bswap 0x2e5e
#define MN_fsubp 0x2e64
#define MN_pfrcp 0x2e6a
#define MN_rdtscp 0x2e70
#define MN_faddp 0x2e77
#define MN_pdep 0x2e7d
#define MN_ffreep 0x2e82
#define MN_rep 0x2e89
#define MN_pushp 0x2e8d
#define MN_fcomip 0x2e93
#define MN_fucomip 0x2e9a
#define MN_jp 0x2ea2
#define MN_fmulp 0x2ea5
#define MN_cmp (MN_scmp + 1)
#define MN_scmp 0x2eab
#define MN_jmp (MN_ljmp + 1)
#define MN_ljmp 0x2eb0
#define MN_fcomp 0x2eb5
#define MN_ficomp 0x2ebb
#define MN_fucomp 0x2ec2
#define MN_jnp 0x2ec9
#define MN_setnp 0x2ecd
#define MN_setzunp 0x2ed3
#define MN_cmovnp (MN_cfcmovnp + 2)
#define MN_cfcmovnp 0x2edb
#define MN_nop (MN_fnop + 1)
#define MN_fnop 0x2ee4
#define MN_loop 0x2ee9
#define MN_pop 0x2eee
#define MN_fcompp 0x2ef2
#define MN_fucompp 0x2ef9
#define MN_popp 0x2f01
#define MN_fsubrp 0x2f06
#define MN_fdivrp 0x2f0d
#define MN_rstorssp 0x2f14
#define MN_saveprevssp 0x2f1d
#define MN_setp 0x2f29
#define MN_fbstp 0x2f2e
#define MN_fdecstp 0x2f34
#define MN_fincstp 0x2f3c
#define MN_fstp 0x2f44
#define MN_fistp 0x2f49
#define MN_fisttp 0x2f4f
#define MN_movddup (MN_vmovddup + 1)
#define MN_vmovddup 0x2f56
#define MN_movshdup (MN_vmovshdup + 1)
#define MN_vmovshdup 0x2f5f
#define MN_movsldup (MN_vmovsldup + 1)
#define MN_vmovsldup 0x2f69
#define MN_setzup 0x2f73
#define MN_fdivp 0x2f7a
#define MN_cmovp (MN_cfcmovp + 2)
#define MN_cfcmovp 0x2f80
#define MN_xmodexp 0x2f88
#define MN_vpbroadcastmb2q 0x2f90
#define MN_vpermi2q 0x2fa0
#define MN_vpmovm2q 0x2fa9
#define MN_movdq2q 0x2fb2
#define MN_vpermt2q 0x2fba
#define MN_vpshaq 0x2fc3
#define MN_vpsraq 0x2fca
#define MN_vphaddbq 0x2fd1
#define MN_vphaddubq 0x2fda
#define MN_psubq (MN_vpsubq + 1)
#define MN_vpsubq 0x2fe4
#define MN_pmovsxbq (MN_vpmovsxbq + 1)
#define MN_vpmovsxbq 0x2feb
#define MN_pmovzxbq (MN_vpmovzxbq + 1)
#define MN_vpmovzxbq 0x2ff5
#define MN_cvttpd2dq (MN_vcvttpd2dq + 1)
#define MN_vcvttpd2dq 0x2fff
#define MN_cvtpd2dq (MN_vcvtpd2dq + 1)
#define MN_vcvtpd2dq 0x300a
#define MN_vcvttph2dq 0x3014
#define MN_vcvtph2dq 0x301f
#define MN_movq2dq 0x3029
#define MN_cvttps2dq (MN_vcvttps2dq + 1)
#define MN_vcvttps2dq 0x3031
#define MN_cvtps2dq (MN_vcvtps2dq + 1)
#define MN_vcvtps2dq 0x303c
#define MN_vphsubdq 0x3046
#define MN_cdq 0x304f
#define MN_kaddq 0x3053
#define MN_paddq (MN_vpaddq + 1)
#define MN_vpaddq 0x3059
#define MN_vphadddq 0x3060
#define MN_punpckhdq (MN_vpunpckhdq + 1)
#define MN_vpunpckhdq 0x3069
#define MN_kunpckdq 0x3074
#define MN_vpshldq 0x307d
#define MN_punpckldq (MN_vpunpckldq + 1)
#define MN_vpunpckldq 0x3085
#define MN_pslldq (MN_vpslldq + 1)
#define MN_vpslldq 0x3090
#define MN_psrldq (MN_vpsrldq + 1)
#define MN_vpsrldq 0x3098
#define MN_pmuldq (MN_vpmuldq + 1)
#define MN_vpmuldq 0x30a0
#define MN_kandq 0x30a8
#define MN_vpandq 0x30ae
#define MN_vpexpandq 0x30b5
#define MN_punpckhqdq (MN_vpunpckhqdq + 1)
#define MN_vpunpckhqdq 0x30bf
#define MN_pclmulhqhqdq (MN_vpclmulhqhqdq + 1)
#define MN_vpclmulhqhqdq 0x30cb
#define MN_pclmullqhqdq (MN_vpclmullqhqdq + 1)
#define MN_vpclmullqhqdq 0x30d9
#define MN_punpcklqdq (MN_vpunpcklqdq + 1)
#define MN_vpunpcklqdq 0x30e7
#define MN_pclmulhqlqdq (MN_vpclmulhqlqdq + 1)
#define MN_vpclmulhqlqdq 0x30f3
#define MN_pclmullqlqdq (MN_vpclmullqlqdq + 1)
#define MN_vpclmullqlqdq 0x3101
#define MN_pclmulqdq (MN_vpclmulqdq + 1)
#define MN_vpclmulqdq 0x310f
#define MN_vpgatherdq 0x311a
#define MN_vpscatterdq 0x3125
#define MN_vpshrdq 0x3131
#define MN_movntdq (MN_vmovntdq + 1)
#define MN_vmovntdq 0x3139
#define MN_vcvttpd2udq 0x3142
#define MN_vcvtpd2udq 0x314e
#define MN_vcvttph2udq 0x3159
#define MN_vcvtph2udq 0x3165
#define MN_vcvttps2udq 0x3170
#define MN_vcvtps2udq 0x317c
#define MN_vphaddudq 0x3187
#define MN_pmuludq (MN_vpmuludq + 1)
#define MN_vpmuludq 0x3191
#define MN_pmovsxdq (MN_vpmovsxdq + 1)
#define MN_vpmovsxdq 0x319a
#define MN_pmovzxdq (MN_vpmovzxdq + 1)
#define MN_vpmovzxdq 0x31a4
#define MN_vpcomgeq 0x31ae
#define MN_vpcomleq 0x31b7
#define MN_vpcmpnleq 0x31c0
#define MN_vpcmpleq 0x31ca
#define MN_pfcmpeq 0x31d3
#define MN_vpcomfalseq 0x31db
#define MN_vpcomtrueq 0x31e7
#define MN_vpternlogq 0x31f2
#define MN_vpshlq 0x31fd
#define MN_psllq (MN_vpsllq + 1)
#define MN_vpsllq 0x3204
#define MN_vpmullq 0x320b
#define MN_vprolq 0x3213
#define MN_psrlq (MN_vpsrlq + 1)
#define MN_vpsrlq 0x321a
#define MN_kshiftlq 0x3221
#define MN_vpblendmq 0x322a
#define MN_vptestnmq 0x3234
#define MN_vpcomq 0x323e
#define MN_vpermq 0x3245
#define MN_vptestmq 0x324c
#define MN_kandnq 0x3255
#define MN_vpandnq 0x325c
#define MN_valignq 0x3264
#define MN_vpcmpq 0x326c
#define MN_incsspq 0x3273
#define MN_rdsspq 0x327b
#define MN_vcvttpd2qq 0x3282
#define MN_vcvtpd2qq 0x328d
#define MN_vcvttph2qq 0x3297
#define MN_vcvtph2qq 0x32a2
#define MN_vcvttps2qq 0x32ac
#define MN_vcvtps2qq 0x32b7
#define MN_vpcomeqq 0x32c1
#define MN_vpcomneqq 0x32ca
#define MN_vpcmpneqq 0x32d4
#define MN_pcmpeqq (MN_vpcmpeqq + 1)
#define MN_vpcmpeqq 0x32de
#define MN_vpgatherqq 0x32e7
#define MN_vpscatterqq 0x32f2
#define MN_vcvttpd2uqq 0x32fe
#define MN_vcvtpd2uqq 0x330a
#define MN_vcvttph2uqq 0x3315
#define MN_vcvtph2uqq 0x3321
#define MN_vcvttps2uqq 0x332c
#define MN_vcvtps2uqq 0x3338
#define MN_korq 0x3343
#define MN_kxnorq 0x3348
#define MN_vporq 0x334f
#define MN_vprorq 0x3355
#define MN_kxorq 0x335c
#define MN_vpxorq 0x3362
#define MN_pinsrq (MN_vpinsrq + 1)
#define MN_vpinsrq 0x3369
#define MN_kshiftrq 0x3371
#define MN_extrq (MN_pextrq + 1)
#define MN_pextrq (MN_vpextrq + 1)
#define MN_vpextrq 0x337a
#define MN_vpabsq 0x3382
#define MN_vpminsq 0x3389
#define MN_vmovrsq 0x3391
#define MN_vpcompressq 0x3399
#define MN_wrssq 0x33a5
#define MN_wrussq 0x33ab
#define MN_vpmaxsq 0x33b2
#define MN_vp2intersectq 0x33ba
#define MN_vpconflictq 0x33c8
#define MN_vpcomgtq 0x33d4
#define MN_pcmpgtq (MN_vpcmpgtq + 1)
#define MN_vpcmpgtq 0x33dd
#define MN_cltq 0x33e6
#define MN_vpcomltq 0x33eb
#define MN_vpcmpnltq 0x33f4
#define MN_vpcmpltq 0x33fe
#define MN_vpopcntq 0x3407
#define MN_vplzcntq 0x3410
#define MN_movntq 0x3419
#define MN_knotq 0x3420
#define MN_vprotq 0x3426
#define MN_insertq 0x342d
#define MN_vpbroadcastq 0x3435
#define MN_ktestq 0x3442
#define MN_kortestq 0x3449
#define MN_vpcomgeuq 0x3452
#define MN_vpcomleuq 0x345c
#define MN_vpcmpnleuq 0x3466
#define MN_vpcmpleuq 0x3471
#define MN_vpcomfalseuq 0x347b
#define MN_vpcomtrueuq 0x3488
#define MN_vpmadd52huq 0x3494
#define MN_vpmadd52luq 0x34a0
#define MN_vpcomuq 0x34ac
#define MN_vpminuq 0x34b4
#define MN_vpcmpuq 0x34bc
#define MN_vpcomequq 0x34c4
#define MN_vpcomnequq 0x34ce
#define MN_vpcmpnequq 0x34d9
#define MN_vpcmpequq 0x34e4
#define MN_vpcomgtuq 0x34ee
#define MN_vpcomltuq 0x34f8
#define MN_vpcmpnltuq 0x3502
#define MN_vpcmpltuq 0x350d
#define MN_vpmaxuq 0x3517
#define MN_vpsravq 0x351f
#define MN_vpshldvq 0x3527
#define MN_vpshrdvq 0x3530
#define MN_vpsllvq 0x3539
#define MN_vprolvq 0x3541
#define MN_vpsrlvq 0x3549
#define MN_movq (MN_kmovq + 1)
#define MN_kmovq (MN_maskmovq + 3)
#define MN_maskmovq (MN_vpmaskmovq + 2)
#define MN_vpmaskmovq 0x3551
#define MN_vmovq 0x355c
#define MN_vprorvq 0x3562
#define MN_vphaddwq 0x356a
#define MN_vphadduwq 0x3573
#define MN_pmovsxwq (MN_vpmovsxwq + 1)
#define MN_vpmovsxwq 0x357d
#define MN_pmovzxwq (MN_vpmovzxwq + 1)
#define MN_vpmovzxwq 0x3587
#define MN_rex_r 0x3591
#define MN_vmclear 0x3597
#define MN_lar 0x359f
#define MN_sar 0x35a3
#define MN_fsubr (MN_pfsubr + 1)
#define MN_pfsubr 0x35a7
#define MN_fisubr 0x35ae
#define MN_rcr 0x35b5
#define MN_vzeroupper 0x35b9
#define MN_enter (MN_sysenter + 3)
#define MN_sysenter 0x35c4
#define MN_shr 0x35cd
#define MN_clr 0x35d1
#define MN_palignr (MN_vpalignr + 1)
#define MN_vpalignr 0x35d5
#define MN_or (MN_aor + 1)
#define MN_aor 0x35de
#define MN_por (MN_vpor + 1)
#define MN_vpor 0x35e2
#define MN_ror 0x35e7
#define MN_monitor (MN_umonitor + 1)
#define MN_umonitor 0x35eb
#define MN_frstor 0x35f4
#define MN_xrstor (MN_fxrstor + 1)
#define MN_fxrstor 0x35fb
#define MN_xor (MN_axor + 1)
#define MN_axor 0x3603
#define MN_pxor (MN_vpxor + 1)
#define MN_vpxor 0x3608
#define MN_verr 0x360e
#define MN_bsr 0x3613
#define MN_ldmxcsr (MN_vldmxcsr + 1)
#define MN_vldmxcsr 0x3617
#define MN_stmxcsr (MN_vstmxcsr + 1)
#define MN_vstmxcsr 0x3620
#define MN_blsr 0x3629
#define MN_rdmsr (MN_urdmsr + 1)
#define MN_urdmsr 0x362e
#define MN_wrmsr (MN_uwrmsr + 1)
#define MN_uwrmsr 0x3635
#define MN_btr 0x363c
#define MN_xcrypt_ctr 0x3640
#define MN_xcryptctr 0x364b
#define MN_ltr 0x3655
#define MN_str 0x3659
#define MN_bextr 0x365d
#define MN_fdivr 0x3663
#define MN_fidivr 0x3669
#define MN_rex_wr 0x3670
#define MN_vcvt2ph2bf8s 0x3677
#define MN_vcvtbiasph2bf8s 0x3684
#define MN_vcvtph2bf8s 0x3694
#define MN_vcvt2ph2hf8s 0x36a0
#define MN_vcvtbiasph2hf8s 0x36ad
#define MN_vcvtph2hf8s 0x36bd
#define MN_aas 0x36c9
#define MN_scas 0x36cd
#define MN_das 0x36d2
#define MN_fabs 0x36d6
#define MN_jmpabs 0x36db
#define MN_movabs 0x36e2
#define MN_vcvttbf162ibs 0x36e9
#define MN_vcvtbf162ibs 0x36f7
#define MN_vcvttph2ibs 0x3704
#define MN_vcvtph2ibs 0x3710
#define MN_vcvttps2ibs 0x371b
#define MN_vcvtps2ibs 0x3727
#define MN_vcvttbf162iubs 0x3732
#define MN_vcvtbf162iubs 0x3741
#define MN_vcvttph2iubs 0x374f
#define MN_vcvtph2iubs 0x375c
#define MN_vcvttps2iubs 0x3768
#define MN_vcvtps2iubs 0x3775
#define MN_cs (MN_blcs + 2)
#define MN_blcs 0x3781
#define MN_ds (MN_lds + 1)
#define MN_lds 0x3786
#define MN_enqcmds 0x378a
#define MN_lods 0x3792
#define MN_vpdpbssds 0x3797
#define MN_vp4dpwssds 0x37a1
#define MN_vpdpwssds 0x37ac
#define MN_vpdpbusds 0x37b6
#define MN_vpdpwusds 0x37c0
#define MN_vpdpbsuds 0x37ca
#define MN_vpdpwsuds 0x37d4
#define MN_vpdpbuuds 0x37de
#define MN_vpdpwuuds 0x37e8
#define MN_es (MN_les + 1)
#define MN_les 0x37f2
#define MN_xsaves 0x37f6
#define MN_fs (MN_lfs + 1)
#define MN_lfs 0x37fd
#define MN_gs (MN_lkgs + 2)
#define MN_lkgs 0x3801
#define MN_lgs 0x3806
#define MN_swapgs 0x380a
#define MN_fchs 0x3811
#define MN_vcvttsd2sis 0x3816
#define MN_vcvttss2sis 0x3822
#define MN_vcvttsd2usis 0x382e
#define MN_vcvttss2usis 0x383b
#define MN_js 0x3848
#define MN_encls 0x384b
#define MN_emms (MN_femms + 1)
#define MN_femms 0x3851
#define MN_ins (MN_lwpins + 3)
#define MN_lwpins 0x3857
#define MN_jns 0x385e
#define MN_ccmpns 0x3862
#define MN_wrmsrns 0x3869
#define MN_setns 0x3871
#define MN_ctestns 0x3877
#define MN_setzuns 0x387f
#define MN_cmovns (MN_cfcmovns + 2)
#define MN_cfcmovns 0x3887
#define MN_fcos 0x3890
#define MN_fsincos 0x3895
#define MN_stos 0x389d
#define MN_vfmaddsub231ps 0x38a2
#define MN_vfmsub231ps 0x38b1
#define MN_vfnmsub231ps 0x38bd
#define MN_vfmsubadd231ps 0x38ca
#define MN_vfmadd231ps 0x38d9
#define MN_vfnmadd231ps 0x38e5
#define MN_vfmaddsub132ps 0x38f2
#define MN_vfmsub132ps 0x3901
#define MN_vfnmsub132ps 0x390d
#define MN_vfmsubadd132ps 0x391a
#define MN_vfmadd132ps 0x3929
#define MN_vfnmadd132ps 0x3935
#define MN_tmmultf32ps (MN_ttmmultf32ps + 1)
#define MN_ttmmultf32ps 0x3942
#define MN_vcvtneebf162ps 0x394f
#define MN_vbcstnebf162ps 0x395e
#define MN_vcvtneobf162ps 0x396d
#define MN_cvtpd2ps (MN_vcvtpd2ps + 1)
#define MN_vcvtpd2ps 0x397c
#define MN_tcvtrowd2ps 0x3986
#define MN_vcvtneeph2ps 0x3992
#define MN_vcvtneoph2ps 0x399f
#define MN_vcvtph2ps 0x39ac
#define MN_vbcstnesh2ps 0x39b6
#define MN_vpermi2ps 0x39c3
#define MN_cvtpi2ps 0x39cd
#define MN_vpermil2ps 0x39d6
#define MN_vexp2ps 0x39e1
#define MN_cvtdq2ps (MN_vcvtdq2ps + 1)
#define MN_vcvtdq2ps 0x39e9
#define MN_vcvtudq2ps 0x39f3
#define MN_vcvtqq2ps 0x39fe
#define MN_vcvtuqq2ps 0x3a08
#define MN_vpermt2ps 0x3a13
#define MN_vfmaddsub213ps 0x3a1d
#define MN_vfmsub213ps 0x3a2c
#define MN_vfnmsub213ps 0x3a38
#define MN_vfmsubadd213ps 0x3a45
#define MN_vfmadd213ps 0x3a54
#define MN_vfnmadd213ps 0x3a60
#define MN_vrcp14ps 0x3a6d
#define MN_vrsqrt14ps 0x3a76
#define MN_tdpbf16ps (MN_ttdpbf16ps + 1)
#define MN_ttdpbf16ps 0x3a81
#define MN_vdpbf16ps 0x3a8c
#define MN_tcmmrlfp16ps (MN_ttcmmrlfp16ps + 1)
#define MN_ttcmmrlfp16ps 0x3a96
#define MN_tcmmimfp16ps (MN_tconjtcmmimfp16ps + 5)
#define MN_tconjtcmmimfp16ps 0x3aa4
#define MN_ttcmmimfp16ps 0x3ab6
#define MN_tdpfp16ps (MN_ttdpfp16ps + 1)
#define MN_ttdpfp16ps 0x3ac4
#define MN_vrcp28ps 0x3acf
#define MN_vrsqrt28ps 0x3ad8
#define MN_tdphbf8ps 0x3ae3
#define MN_tdpbf8ps 0x3aed
#define MN_tdpbhf8ps 0x3af6
#define MN_tdphf8ps 0x3b00
#define MN_movaps (MN_vmovaps + 1)
#define MN_vmovaps 0x3b09
#define MN_subps (MN_addsubps + 3)
#define MN_addsubps (MN_vfmaddsubps + 3)
#define MN_vfmaddsubps 0x3b11
#define MN_vaddsubps 0x3b1d
#define MN_hsubps (MN_vhsubps + 1)
#define MN_vhsubps 0x3b27
#define MN_vfmsubps 0x3b2f
#define MN_vfnmsubps 0x3b38
#define MN_vsubps 0x3b42
#define MN_vgatherpf0dps 0x3b49
#define MN_vscatterpf0dps 0x3b57
#define MN_vgatherpf1dps 0x3b66
#define MN_vscatterpf1dps 0x3b74
#define MN_addps (MN_vfmsubaddps + 6)
#define MN_vfmsubaddps 0x3b83
#define MN_haddps (MN_vhaddps + 1)
#define MN_vhaddps 0x3b8f
#define MN_v4fmaddps 0x3b97
#define MN_vfmaddps 0x3ba1
#define MN_v4fnmaddps 0x3baa
#define MN_vfnmaddps 0x3bb5
#define MN_vaddps 0x3bbf
#define MN_andps (MN_vexpandps + 4)
#define MN_vexpandps 0x3bc6
#define MN_vandps 0x3bd0
#define MN_blendps (MN_vblendps + 1)
#define MN_vblendps 0x3bd7
#define MN_roundps (MN_vroundps + 1)
#define MN_vroundps 0x3be0
#define MN_vgatherdps 0x3be9
#define MN_vscatterdps 0x3bf4
#define MN_cmpunordps (MN_vcmpunordps + 1)
#define MN_vcmpunordps 0x3c00
#define MN_cmpordps (MN_vcmpordps + 1)
#define MN_vcmpordps 0x3c0c
#define MN_vreduceps 0x3c16
#define MN_vrangeps 0x3c20
#define MN_vcmpngeps 0x3c29
#define MN_vcmpgeps 0x3c33
#define MN_vrndscaleps 0x3c3c
#define MN_cmpnleps (MN_vcmpnleps + 1)
#define MN_vcmpnleps 0x3c48
#define MN_cmpleps (MN_vcmpleps + 1)
#define MN_vcmpleps 0x3c52
#define MN_vcmpfalseps 0x3c5b
#define MN_vcmptrueps 0x3c67
#define MN_vscalefps 0x3c72
#define MN_shufps (MN_vshufps + 1)
#define MN_vshufps 0x3c7c
#define MN_unpckhps (MN_vunpckhps + 1)
#define MN_vunpckhps 0x3c84
#define MN_movlhps (MN_vmovlhps + 1)
#define MN_vmovlhps 0x3c8e
#define MN_vdpphps 0x3c97
#define MN_movhps (MN_vmovhps + 1)
#define MN_vmovhps 0x3c9f
#define MN_movmskps (MN_vmovmskps + 1)
#define MN_vmovmskps 0x3ca7
#define MN_movhlps (MN_vmovhlps + 1)
#define MN_vmovhlps 0x3cb1
#define MN_vpermilps 0x3cba
#define MN_unpcklps (MN_vunpcklps + 1)
#define MN_vunpcklps 0x3cc4
#define MN_mulps (MN_vmulps + 1)
#define MN_vmulps 0x3cce
#define MN_movlps (MN_vmovlps + 1)
#define MN_vmovlps 0x3cd5
#define MN_cmps (MN_ccmps + 1)
#define MN_ccmps 0x3cdd
#define MN_vblendmps 0x3ce3
#define MN_vfixupimmps 0x3ced
#define MN_vpermps 0x3cf9
#define MN_andnps (MN_vandnps + 1)
#define MN_vandnps 0x3d01
#define MN_minps (MN_vminps + 1)
#define MN_vminps 0x3d09
#define MN_seamops 0x3d10
#define MN_rcpps (MN_vrcpps + 1)
#define MN_vrcpps 0x3d18
#define MN_dpps (MN_vdpps + 1)
#define MN_vdpps 0x3d1f
#define MN_cmpps (MN_vcmpps + 1)
#define MN_vcmpps 0x3d25
#define MN_vgetexpps 0x3d2c
#define MN_vgatherpf0qps 0x3d36
#define MN_vscatterpf0qps 0x3d44
#define MN_vgatherpf1qps 0x3d53
#define MN_vscatterpf1qps 0x3d61
#define MN_vcmpunord_qps 0x3d70
#define MN_vcmpord_qps 0x3d7e
#define MN_cmpneqps (MN_vcmpneqps + 1)
#define MN_vcmpneqps 0x3d8a
#define MN_cmpeqps (MN_vcmpeqps + 1)
#define MN_vcmpeqps 0x3d94
#define MN_vcmpge_oqps 0x3d9d
#define MN_vcmple_oqps 0x3da9
#define MN_vcmpfalse_oqps 0x3db5
#define MN_vcmpneq_oqps 0x3dc4
#define MN_vcmpeq_oqps 0x3dd1
#define MN_vcmpgt_oqps 0x3ddd
#define MN_vcmplt_oqps 0x3de9
#define MN_vgatherqps 0x3df5
#define MN_vscatterqps 0x3e00
#define MN_vcmpnge_uqps 0x3e0c
#define MN_vcmpnle_uqps 0x3e19
#define MN_vcmptrue_uqps 0x3e26
#define MN_vcmpneq_uqps 0x3e34
#define MN_vcmpeq_uqps 0x3e41
#define MN_vcmpngt_uqps 0x3e4d
#define MN_vcmpnlt_uqps 0x3e5a
#define MN_orps (MN_vorps + 1)
#define MN_vorps 0x3e67
#define MN_xorps (MN_vxorps + 1)
#define MN_vxorps 0x3e6d
#define MN_vcmpunord_sps 0x3e74
#define MN_vcmpord_sps 0x3e82
#define MN_vcmpge_osps 0x3e8e
#define MN_vcmple_osps 0x3e9a
#define MN_vcmpfalse_osps 0x3ea6
#define MN_vcmpneq_osps 0x3eb5
#define MN_vcmpeq_osps 0x3ec2
#define MN_vcmpgt_osps 0x3ece
#define MN_vcmplt_osps 0x3eda
#define MN_vfpclassps 0x3ee6
#define MN_vcompressps 0x3ef1
#define MN_vcmpnge_usps 0x3efd
#define MN_vcmpnle_usps 0x3f0a
#define MN_vcmptrue_usps 0x3f17
#define MN_vcmpneq_usps 0x3f25
#define MN_vcmpeq_usps 0x3f32
#define MN_vcmpngt_usps 0x3f3e
#define MN_vcmpnlt_usps 0x3f4b
#define MN_extractps (MN_vextractps + 1)
#define MN_vextractps 0x3f58
#define MN_vcmpngtps 0x3f63
#define MN_vcmpgtps 0x3f6d
#define MN_cmpnltps (MN_vcmpnltps + 1)
#define MN_vcmpnltps 0x3f76
#define MN_cmpltps (MN_vcmpltps + 1)
#define MN_vcmpltps 0x3f80
#define MN_vgetmantps 0x3f89
#define MN_movntps (MN_vmovntps + 1)
#define MN_vmovntps 0x3f94
#define MN_insertps (MN_vinsertps + 1)
#define MN_vinsertps 0x3f9d
#define MN_sqrtps (MN_rsqrtps + 1)
#define MN_rsqrtps (MN_vrsqrtps + 1)
#define MN_vrsqrtps 0x3fa7
#define MN_vsqrtps 0x3fb0
#define MN_vtestps 0x3fb8
#define MN_movups (MN_vmovups + 1)
#define MN_vmovups 0x3fc0
#define MN_blendvps (MN_vblendvps + 1)
#define MN_vblendvps 0x3fc8
#define MN_divps (MN_vdivps + 1)
#define MN_vdivps 0x3fd2
#define MN_vmaskmovps 0x3fd9
#define MN_maxps (MN_vminmaxps + 4)
#define MN_vminmaxps 0x3fe4
#define MN_vmaxps 0x3fee
#define MN_vfrczps 0x3ff5
#define MN_vcvttpd2dqs 0x3ffd
#define MN_vcvttps2dqs 0x4009
#define MN_vcvttpd2udqs 0x4015
#define MN_vcvttps2udqs 0x4022
#define MN_vcvttpd2qqs 0x402f
#define MN_vcvttps2qqs 0x403b
#define MN_vcvttpd2uqqs 0x4047
#define MN_vcvttps2uqqs 0x4054
#define MN_t2rpntlvwz0rs 0x4061
#define MN_t2rpntlvwz1rs 0x406f
#define MN_tileloaddrs 0x407d
#define MN_xrstors 0x4089
#define MN_movrs 0x4091
#define MN_ss (MN_vfmsub231ss + 9)
#define MN_vfmsub231ss 0x4097
#define MN_vfnmsub231ss 0x40a3
#define MN_vfmadd231ss 0x40b0
#define MN_vfnmadd231ss 0x40bc
#define MN_vfmsub132ss 0x40c9
#define MN_vfnmsub132ss 0x40d5
#define MN_vfmadd132ss 0x40e2
#define MN_vfnmadd132ss 0x40ee
#define MN_cvtsd2ss (MN_vcvtsd2ss + 1)
#define MN_vcvtsd2ss 0x40fb
#define MN_vcvtsh2ss 0x4105
#define MN_cvtsi2ss (MN_vcvtsi2ss + 1)
#define MN_vcvtsi2ss 0x410f
#define MN_vcvtusi2ss 0x4119
#define MN_vfmsub213ss 0x4124
#define MN_vfnmsub213ss 0x4130
#define MN_vfmadd213ss 0x413d
#define MN_vfnmadd213ss 0x4149
#define MN_vrcp14ss 0x4156
#define MN_vrsqrt14ss 0x415f
#define MN_vrcp28ss 0x416a
#define MN_vrsqrt28ss 0x4173
#define MN_subss (MN_vfmsubss + 3)
#define MN_vfmsubss 0x417e
#define MN_vfnmsubss 0x4187
#define MN_vsubss 0x4191
#define MN_addss (MN_v4fmaddss + 4)
#define MN_v4fmaddss 0x4198
#define MN_vfmaddss 0x41a2
#define MN_v4fnmaddss 0x41ab
#define MN_vfnmaddss 0x41b6
#define MN_vaddss 0x41c0
#define MN_roundss (MN_vroundss + 1)
#define MN_vroundss 0x41c7
#define MN_cmpunordss (MN_vcmpunordss + 1)
#define MN_vcmpunordss 0x41d0
#define MN_cmpordss (MN_vcmpordss + 1)
#define MN_vcmpordss 0x41dc
#define MN_vreducess 0x41e6
#define MN_vrangess 0x41f0
#define MN_vcmpngess 0x41f9
#define MN_vcmpgess 0x4203
#define MN_vrndscaless 0x420c
#define MN_cmpnless (MN_vcmpnless + 1)
#define MN_vcmpnless 0x4218
#define MN_cmpless (MN_vcmpless + 1)
#define MN_vcmpless 0x4222
#define MN_vcmpfalsess 0x422b
#define MN_vcmptruess 0x4237
#define MN_vscalefss 0x4242
#define MN_comiss (MN_ucomiss + 1)
#define MN_ucomiss (MN_vucomiss + 1)
#define MN_vucomiss 0x424c
#define MN_vcomiss 0x4255
#define MN_lss (MN_mulss + 2)
#define MN_mulss (MN_vmulss + 1)
#define MN_vmulss 0x425d
#define MN_vfixupimmss 0x4264
#define MN_minss (MN_vminss + 1)
#define MN_vminss 0x4270
#define MN_rcpss (MN_vrcpss + 1)
#define MN_vrcpss 0x4277
#define MN_cmpss (MN_vcmpss + 1)
#define MN_vcmpss 0x427e
#define MN_vgetexpss 0x4285
#define MN_vcmpunord_qss 0x428f
#define MN_vcmpord_qss 0x429d
#define MN_cmpneqss (MN_vcmpneqss + 1)
#define MN_vcmpneqss 0x42a9
#define MN_cmpeqss (MN_vcmpeqss + 1)
#define MN_vcmpeqss 0x42b3
#define MN_vcmpge_oqss 0x42bc
#define MN_vcmple_oqss 0x42c8
#define MN_vcmpfalse_oqss 0x42d4
#define MN_vcmpneq_oqss 0x42e3
#define MN_vcmpeq_oqss 0x42f0
#define MN_vcmpgt_oqss 0x42fc
#define MN_vcmplt_oqss 0x4308
#define MN_vcmpnge_uqss 0x4314
#define MN_vcmpnle_uqss 0x4321
#define MN_vcmptrue_uqss 0x432e
#define MN_vcmpneq_uqss 0x433c
#define MN_vcmpeq_uqss 0x4349
#define MN_vcmpngt_uqss 0x4355
#define MN_vcmpnlt_uqss 0x4362
#define MN_vcmpunord_sss 0x436f
#define MN_vcmpord_sss 0x437d
#define MN_vcmpge_osss 0x4389
#define MN_vcmple_osss 0x4395
#define MN_vcmpfalse_osss 0x43a1
#define MN_vcmpneq_osss 0x43b0
#define MN_vcmpeq_osss 0x43bd
#define MN_vcmpgt_osss 0x43c9
#define MN_vcmplt_osss 0x43d5
#define MN_vfpclassss 0x43e1
#define MN_vcmpnge_usss 0x43ec
#define MN_vcmpnle_usss 0x43f9
#define MN_vcmptrue_usss 0x4406
#define MN_vcmpneq_usss 0x4414
#define MN_vcmpeq_usss 0x4421
#define MN_vcmpngt_usss 0x442d
#define MN_vcmpnlt_usss 0x443a
#define MN_vcmpngtss 0x4447
#define MN_vcmpgtss 0x4451
#define MN_cmpnltss (MN_vcmpnltss + 1)
#define MN_vcmpnltss 0x445a
#define MN_cmpltss (MN_vcmpltss + 1)
#define MN_vcmpltss 0x4464
#define MN_vgetmantss 0x446d
#define MN_movntss 0x4478
#define MN_sqrtss (MN_rsqrtss + 1)
#define MN_rsqrtss (MN_vrsqrtss + 1)
#define MN_vrsqrtss 0x4480
#define MN_vsqrtss 0x4489
#define MN_vbroadcastss 0x4491
#define MN_divss (MN_vdivss + 1)
#define MN_vdivss 0x449e
#define MN_movss (MN_vmovss + 1)
#define MN_vmovss 0x44a5
#define MN_maxss (MN_vminmaxss + 4)
#define MN_vminmaxss 0x44ac
#define MN_vmaxss 0x44b6
#define MN_vucomxss 0x44bd
#define MN_vcomxss 0x44c6
#define MN_vfrczss 0x44ce
#define MN_bts 0x44d6
#define MN_erets 0x44da
#define MN_sets 0x44e0
#define MN_clts 0x44e5
#define MN_ctests 0x44ea
#define MN_outs 0x44f1
#define MN_setzus 0x44f6
#define MN_movs (MN_cmovs + 1)
#define MN_cmovs (MN_cfcmovs + 2)
#define MN_cfcmovs 0x44fd
#define MN_fldl2t 0x4505
#define MN_xlat 0x450c
#define MN_bt 0x4511
#define MN_fxtract 0x4514
#define MN_lgdt 0x451c
#define MN_sgdt 0x4521
#define MN_lidt 0x4526
#define MN_sidt 0x452b
#define MN_fldt 0x4530
#define MN_lldt 0x4535
#define MN_sldt 0x453a
#define MN_ret (MN_iret + 1)
#define MN_iret (MN_uiret + 1)
#define MN_uiret 0x453f
#define MN_lret 0x4545
#define MN_seamret 0x454a
#define MN_sysret 0x4552
#define MN_hreset 0x4559
#define MN_pfcmpgt 0x4560
#define MN_ht 0x4568
#define MN_wait (MN_fwait + 1)
#define MN_fwait 0x456b
#define MN_mwait (MN_umwait + 1)
#define MN_umwait 0x4571
#define MN_mcommit 0x4578
#define MN_finit 0x4580
#define MN_skinit 0x4586
#define MN_fninit 0x458d
#define MN_vmgexit 0x4594
#define MN_sysexit 0x459c
#define MN_hlt 0x45a4
#define MN_popcnt 0x45a8
#define MN_lzcnt 0x45af
#define MN_tzcnt 0x45b5
#define MN_hnt 0x45bb
#define MN_int (MN_frndint + 4)
#define MN_frndint 0x45bf
#define MN_not 0x45c7
#define MN_invept 0x45cb
#define MN_ccmpt 0x45d2
#define MN_xsaveopt 0x45d8
#define MN_clflushopt 0x45e1
#define MN_fstpt 0x45ec
#define MN_xabort 0x45f2
#define MN_fsqrt 0x45f9
#define MN_pfrsqrt 0x45ff
#define MN_aesdeclast (MN_vaesdeclast + 1)
#define MN_vaesdeclast 0x4607
#define MN_aesenclast (MN_vaesenclast + 1)
#define MN_vaesenclast 0x4613
#define MN_test (MN_ptest + 1)
#define MN_ptest (MN_vptest + 1)
#define MN_vptest 0x461f
#define MN_xtest 0x4626
#define MN_fst 0x462c
#define MN_fist 0x4630
#define MN_rdmsrlist 0x4635
#define MN_wrmsrlist 0x463f
#define MN_aeskeygenassist (MN_vaeskeygenassist + 1)
#define MN_vaeskeygenassist 0x4649
#define MN_vmptrst 0x465a
#define MN_ftst 0x4662
#define MN_rmpadjust 0x4667
#define MN_ctestt 0x4671
#define MN_out 0x4678
#define MN_pext 0x467c
#define MN_bndcu 0x4681
#define MN_enclu 0x4687
#define MN_fcmovnu 0x468d
#define MN_lddqu (MN_vlddqu + 1)
#define MN_vlddqu 0x4695
#define MN_movdqu (MN_maskmovdqu + 4)
#define MN_maskmovdqu (MN_vmaskmovdqu + 1)
#define MN_vmaskmovdqu 0x469c
#define MN_vmovdqu 0x46a8
#define MN_rdpkru 0x46b0
#define MN_wrpkru 0x46b7
#define MN_rdpru 0x46be
#define MN_eretu 0x46c4
#define MN_fcmovu 0x46ca
#define MN_imulzu 0x46d1
#define MN_xgetbv 0x46d8
#define MN_xsetbv 0x46df
#define MN_div (MN_fdiv + 1)
#define MN_fdiv 0x46e6
#define MN_idiv (MN_fidiv + 1)
#define MN_fidiv 0x46eb
#define MN_enclv 0x46f1
#define MN_fldenv 0x46f7
#define MN_fstenv 0x46fe
#define MN_fnstenv 0x4705
#define MN_mov (MN_vpcmov + 3)
#define MN_vpcmov 0x470d
#define MN_bndmov 0x4714
#define MN_smov 0x471b
#define MN_rex_w 0x4720
#define MN_vcvttph2w 0x4726
#define MN_vcvtph2w 0x4730
#define MN_vpermi2w 0x4739
#define MN_vpmovm2w 0x4742
#define MN_vpermt2w 0x474b
#define MN_vpshaw 0x4754
#define MN_psraw (MN_vpsraw + 1)
#define MN_vpsraw 0x475b
#define MN_vphsubbw 0x4762
#define MN_cbw 0x476b
#define MN_psadbw (MN_vdbpsadbw + 3)
#define MN_vdbpsadbw 0x476f
#define MN_mpsadbw (MN_vmpsadbw + 1)
#define MN_vmpsadbw 0x4779
#define MN_vpsadbw 0x4782
#define MN_vphaddbw 0x478a
#define MN_punpckhbw (MN_vpunpckhbw + 1)
#define MN_vpunpckhbw 0x4793
#define MN_kunpckbw 0x479e
#define MN_punpcklbw (MN_vpunpcklbw + 1)
#define MN_vpunpcklbw 0x47a7
#define MN_vphaddubw 0x47b2
#define MN_phsubw (MN_vphsubw + 1)
#define MN_vphsubw 0x47bc
#define MN_psubw (MN_vpsubw + 1)
#define MN_vpsubw 0x47c4
#define MN_pmovsxbw (MN_vpmovsxbw + 1)
#define MN_vpmovsxbw 0x47cb
#define MN_pmovzxbw (MN_vpmovzxbw + 1)
#define MN_vpmovzxbw 0x47d5
#define MN_fldcw 0x47df
#define MN_fstcw 0x47e5
#define MN_fnstcw 0x47eb
#define MN_phaddw (MN_vphaddw + 1)
#define MN_vphaddw 0x47f2
#define MN_kaddw 0x47fa
#define MN_paddw (MN_vpaddw + 1)
#define MN_vpaddw 0x4800
#define MN_vpshldw 0x4807
#define MN_kandw 0x480f
#define MN_vpexpandw 0x4815
#define MN_pblendw (MN_vpblendw + 1)
#define MN_vpblendw 0x481f
#define MN_vpshrdw 0x4828
#define MN_packssdw (MN_vpackssdw + 1)
#define MN_vpackssdw 0x4830
#define MN_packusdw (MN_vpackusdw + 1)
#define MN_vpackusdw 0x483a
#define MN_vpmovusdw 0x4844
#define MN_vpmovsdw 0x484e
#define MN_vpmovdw 0x4857
#define MN_vpcomgew 0x485f
#define MN_vpcomlew 0x4868
#define MN_vpcmpnlew 0x4871
#define MN_vpcmplew 0x487b
#define MN_vpcomfalsew 0x4884
#define MN_vpcomtruew 0x4890
#define MN_pi2fw 0x489b
#define MN_pshufw 0x48a1
#define MN_pavgw (MN_vpavgw + 1)
#define MN_vpavgw 0x48a8
#define MN_prefetchw 0x48af
#define MN_pshufhw (MN_vpshufhw + 1)
#define MN_vpshufhw 0x48b9
#define MN_pmulhw (MN_vpmulhw + 1)
#define MN_vpmulhw 0x48c2
#define MN_pf2iw 0x48ca
#define MN_pshuflw (MN_vpshuflw + 1)
#define MN_vpshuflw 0x48d0
#define MN_vpshlw 0x48d9
#define MN_psllw (MN_vpsllw + 1)
#define MN_vpsllw 0x48e0
#define MN_pmullw (MN_vpmullw + 1)
#define MN_vpmullw 0x48e7
#define MN_psrlw (MN_vpsrlw + 1)
#define MN_vpsrlw 0x48ef
#define MN_kshiftlw 0x48f6
#define MN_vpblendmw 0x48ff
#define MN_vptestnmw 0x4909
#define MN_vpcomw 0x4913
#define MN_vpermw 0x491a
#define MN_vptestmw 0x4921
#define MN_kandnw 0x492a
#define MN_psignw (MN_vpsignw + 1)
#define MN_vpsignw 0x4931
#define MN_tilemovrow 0x4939
#define MN_vpcmpw 0x4944
#define MN_vpcomeqw 0x494b
#define MN_vpcomneqw 0x4954
#define MN_vpcmpneqw 0x495e
#define MN_pcmpeqw (MN_vpcmpeqw + 1)
#define MN_vpcmpeqw 0x4968
#define MN_vpmovusqw 0x4971
#define MN_vpmovsqw 0x497b
#define MN_vpmovqw 0x4984
#define MN_verw 0x498c
#define MN_pmulhrw 0x4991
#define MN_korw 0x4999
#define MN_kxnorw 0x499e
#define MN_kxorw 0x49a5
#define MN_pinsrw (MN_vpinsrw + 1)
#define MN_vpinsrw 0x49ab
#define MN_kshiftrw 0x49b3
#define MN_pextrw (MN_vpextrw + 1)
#define MN_vpextrw 0x49bc
#define MN_pabsw (MN_vpabsw + 1)
#define MN_vpabsw 0x49c4
#define MN_pmaddubsw (MN_vpmaddubsw + 1)
#define MN_vpmaddubsw 0x49cb
#define MN_phsubsw (MN_vphsubsw + 1)
#define MN_vphsubsw 0x49d6
#define MN_psubsw (MN_vpsubsw + 1)
#define MN_vpsubsw 0x49df
#define MN_phaddsw (MN_vphaddsw + 1)
#define MN_vphaddsw 0x49e7
#define MN_paddsw (MN_vpaddsw + 1)
#define MN_vpaddsw 0x49f0
#define MN_lmsw 0x49f8
#define MN_smsw 0x49fd
#define MN_pminsw (MN_vpminsw + 1)
#define MN_vpminsw 0x4a02
#define MN_pmulhrsw (MN_vpmulhrsw + 1)
#define MN_vpmulhrsw 0x4a0a
#define MN_vmovrsw 0x4a14
#define MN_vpcompressw 0x4a1c
#define MN_fstsw 0x4a28
#define MN_fnstsw 0x4a2e
#define MN_psubusw (MN_vpsubusw + 1)
#define MN_vpsubusw 0x4a35
#define MN_paddusw (MN_vpaddusw + 1)
#define MN_vpaddusw 0x4a3e
#define MN_movsw 0x4a47
#define MN_pmaxsw (MN_vpmaxsw + 1)
#define MN_vpmaxsw 0x4a4d
#define MN_cbtw 0x4a55
#define MN_vpcomgtw 0x4a5a
#define MN_pcmpgtw (MN_vpcmpgtw + 1)
#define MN_vpcmpgtw 0x4a63
#define MN_vpcomltw 0x4a6c
#define MN_vpcmpnltw 0x4a75
#define MN_vpcmpltw 0x4a7f
#define MN_vpopcntw 0x4a88
#define MN_knotw 0x4a91
#define MN_vprotw 0x4a97
#define MN_vpbroadcastw 0x4a9e
#define MN_ktestw 0x4aab
#define MN_kortestw 0x4ab2
#define MN_vcvttph2uw 0x4abb
#define MN_vcvtph2uw 0x4ac6
#define MN_vpcomgeuw 0x4ad0
#define MN_vpcomleuw 0x4ada
#define MN_vpcmpnleuw 0x4ae4
#define MN_vpcmpleuw 0x4aef
#define MN_vpcomfalseuw 0x4af9
#define MN_vpcomtrueuw 0x4b06
#define MN_pmulhuw (MN_vpmulhuw + 1)
#define MN_vpmulhuw 0x4b12
#define MN_vpcomuw 0x4b1b
#define MN_pminuw (MN_vpminuw + 1)
#define MN_vpminuw 0x4b23
#define MN_vpcmpuw 0x4b2b
#define MN_vpcomequw 0x4b33
#define MN_vpcomnequw 0x4b3d
#define MN_vpcmpnequw 0x4b48
#define MN_vpcmpequw 0x4b53
#define MN_phminposuw (MN_vphminposuw + 1)
#define MN_vphminposuw 0x4b5d
#define MN_vpcomgtuw 0x4b69
#define MN_vpcomltuw 0x4b73
#define MN_vpcmpnltuw 0x4b7d
#define MN_vpcmpltuw 0x4b88
#define MN_pmaxuw (MN_vpmaxuw + 1)
#define MN_vpmaxuw 0x4b92
#define MN_vpsravw 0x4b9a
#define MN_vpshldvw 0x4ba2
#define MN_vpshrdvw 0x4bab
#define MN_vpsllvw 0x4bb4
#define MN_vpsrlvw 0x4bbc
#define MN_kmovw 0x4bc4
#define MN_vmovw 0x4bca
#define MN_vpmacsww 0x4bd0
#define MN_vpmacssww 0x4bd9
#define MN_movzw 0x4be3
#define MN_rex_x 0x4be9
#define MN_fyl2x 0x4bef
#define MN_rex64x 0x4bf5
#define MN_vcvtneps2bf16x 0x4bfc
#define MN_vfpclassbf16x 0x4c0b
#define MN_vcvtph2bf8x 0x4c19
#define MN_vcvtph2hf8x 0x4c25
#define MN_pfmax 0x4c31
#define MN_adcx 0x4c37
#define MN_bndldx 0x4c3c
#define MN_vfpclasspdx 0x4c43
#define MN_fclex 0x4c4f
#define MN_fnclex 0x4c55
#define MN_rex 0x4c5c
#define MN_vcvtpd2phx 0x4c60
#define MN_vcvtdq2phx 0x4c6b
#define MN_vcvtudq2phx 0x4c76
#define MN_vcvtqq2phx 0x4c82
#define MN_vcvtuqq2phx 0x4c8d
#define MN_vcvt2ps2phx 0x4c99
#define MN_vcvtps2phx 0x4ca5
#define MN_vfpclassphx 0x4cb0
#define MN_shlx 0x4cbc
#define MN_mulx 0x4cc1
#define MN_adox 0x4cc6
#define MN_vcvttpd2dqx 0x4ccb
#define MN_vcvtpd2dqx 0x4cd7
#define MN_vcvttpd2udqx 0x4ce2
#define MN_vcvtpd2udqx 0x4cef
#define MN_rex_rx 0x4cfb
#define MN_sarx 0x4d02
#define MN_shrx 0x4d07
#define MN_rorx 0x4d0c
#define MN_monitorx 0x4d11
#define MN_rex_wrx 0x4d1a
#define MN_vcvtph2bf8sx 0x4d22
#define MN_vcvtph2hf8sx 0x4d2f
#define MN_vcvtpd2psx 0x4d3c
#define MN_vcvtph2psx 0x4d47
#define MN_vcvtqq2psx 0x4d52
#define MN_vcvtuqq2psx 0x4d5d
#define MN_vfpclasspsx 0x4d69
#define MN_vcvttpd2dqsx 0x4d75
#define MN_vcvttpd2udqsx 0x4d82
#define MN_movsx 0x4d90
#define MN_mwaitx 0x4d96
#define MN_bndstx 0x4d9d
#define MN_rex_wx 0x4da4
#define MN_rexx 0x4dab
#define MN_vcvtps2phxx 0x4db0
#define MN_movzx 0x4dbc
#define MN_rex64y 0x4dc2
#define MN_vcvtneps2bf16y 0x4dc9
#define MN_vfpclassbf16y 0x4dd8
#define MN_vcvtph2bf8y 0x4de6
#define MN_vcvtph2hf8y 0x4df2
#define MN_vfpclasspdy 0x4dfe
#define MN_loadiwkey 0x4e0a
#define MN_vcvtpd2phy 0x4e14
#define MN_vcvtdq2phy 0x4e1f
#define MN_vcvtudq2phy 0x4e2a
#define MN_vcvtqq2phy 0x4e36
#define MN_vcvtuqq2phy 0x4e41
#define MN_vfpclassphy 0x4e4d
#define MN_vcvttpd2dqy 0x4e59
#define MN_vcvtpd2dqy 0x4e65
#define MN_vcvttpd2udqy 0x4e70
#define MN_vcvtpd2udqy 0x4e7d
#define MN_rmpquery 0x4e89
#define MN_vcvtph2bf8sy 0x4e92
#define MN_vcvtph2hf8sy 0x4e9f
#define MN_clrssbsy 0x4eac
#define MN_setssbsy 0x4eb5
#define MN_vcvtpd2psy 0x4ebe
#define MN_vcvtqq2psy 0x4ec9
#define MN_vcvtuqq2psy 0x4ed4
#define MN_vfpclasspsy 0x4ee0
#define MN_vcvttpd2dqsy 0x4eec
#define MN_vcvttpd2udqsy 0x4ef9
#define MN_rex64xy 0x4f07
#define MN_rexy 0x4f0f
#define MN_vcvtps2phxy 0x4f14
#define MN_rexxy 0x4f20
#define MN_rex64z 0x4f26
#define MN_vfpclassbf16z 0x4f2d
#define MN_fldz 0x4f3b
#define MN_vfpclasspdz 0x4f40
#define MN_vcvtpd2phz 0x4f4c
#define MN_vcvtqq2phz 0x4f57
#define MN_vcvtuqq2phz 0x4f62
#define MN_vfpclassphz 0x4f6e
#define MN_jz 0x4f7a
#define MN_jnz 0x4f7d
#define MN_repnz 0x4f81
#define MN_ccmpnz 0x4f87
#define MN_loopnz 0x4f8e
#define MN_setnz 0x4f95
#define MN_ctestnz 0x4f9b
#define MN_setzunz 0x4fa3
#define MN_cmovnz (MN_cfcmovnz + 2)
#define MN_cfcmovnz 0x4fab
#define MN_repz 0x4fb4
#define MN_ccmpz 0x4fb9
#define MN_loopz 0x4fbf
#define MN_vfpclasspsz 0x4fc5
#define MN_setz 0x4fd1
#define MN_ctestz 0x4fd6
#define MN_setzuz 0x4fdd
#define MN_cmovz (MN_cfcmovz + 2)
#define MN_cfcmovz 0x4fe4
#define MN_rex64xz 0x4fec
#define MN_jecxz 0x4ff4
#define MN_jcxz 0x4ffa
#define MN_jrcxz 0x4fff
#define MN_rexz 0x5005
#define MN_rexxz 0x500a
#define MN_rex64yz 0x5010
#define MN_rex64xyz 0x5018
#define MN_rexyz 0x5021
#define MN_rexxyz 0x5027
#define MN__disp32_ 0x502e
#define MN__rex2_ 0x5037
#define MN__vex2_ 0x503e
#define MN__vex3_ 0x5045
#define MN__disp16_ 0x504c
#define MN__disp8_ 0x5055
#define MN__load_ 0x505d
#define MN__store_ 0x5064
#define MN__nooptimize_ 0x506c
#define MN__nf_ 0x5079
#define MN__noimm8s_ 0x507e
#define MN__rex_ 0x5088
#define MN__evex_ 0x508e
#define MN__vex_ 0x5095
#define MN__insn 0x509b
